window.Gleam.initSearch([{"doc":"gleam_community_maths","title":"gleam_community_maths","content":"# gleam-community/maths\n\n[![Package Version](https://img.shields.io/hexpm/v/gleam_community_maths)](https://hex.pm/packages/gleam_community_maths)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleam_community_maths/)\n\nA basic mathematics library that contains some of the most fundamental mathematics functions and utilities.\n\nThe library supports both targets: Erlang and JavaScript.\n\n## Quickstart\n\n```gleam\nimport gleam_community/maths/arithmetics\nimport gleam_community/maths/combinatorics\nimport gleam_community/maths/elementary\nimport gleam_community/maths/piecewise\nimport gleam_community/maths/predicates\nimport gleam/float\n\npub fn main() {\n  // Evaluate the sine function\n  elementary.sin(elementary.pi())\n  // Returns Float: 0.0\n\n  // Find the greatest common divisor\n  arithmetics.gcd(54, 24)\n  // Returns Int: 6\n\n  // Find the minimum and maximum of a list\n  piecewise.extrema([10.0, 3.0, 50.0, 20.0, 3.0], float.compare)\n  // Returns Tuple: Ok(#(3.0, 50.0))\n\n  // Find the list indices of the smallest value \n  piecewise.arg_minimum([10, 3, 50, 20, 3], float.compare)\n  // Returns List: Ok([1, 4])\n\n  // Determine if a number is fractional\n  predicates.is_fractional(0.3333)\n  // Returns Bool: True\n\n  // Determine if 28 is a power of 3\n  predicates.is_power(28, 3)\n  // Returns Bool: False\n\n  // Generate all k = 1 combinations of [1, 2]\n  combinatorics.list_combination([1, 2], 1)\n  // Returns List: Ok([[1], [2]])\n}\n\n```\n\n## Installation\n\n`gleam_community` packages are published to [hex.pm](https://hex.pm/packages/gleam_community_maths)\nwith the prefix `gleam_community_`. You can add them to your Gleam projects directly:\n\n```sh\ngleam add gleam_community_maths\n```\n","url":"index.html"},{"doc":"gleam_community/maths/elementary","title":"acos","content":"pub fn acos(x: Float) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The inverse cosine function:\n\n \\\\[\n \\forall x \\in \\[-1, 1\\],   \\\\; \\cos^{-1}{(x)} = y \\in \\[0, \\pi \\]\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\[-1, 1\\]$$ as input and returns a\n numeric value $$y$$ that lies in the range $$\\[0, \\pi \\]$$ (an angle in radians).\n If the input value is outside the domain of the function an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.acos(1.0)\n       |&gt; should.equal(Ok(0.0))\n\n       elementary.acos(1.1)\n       |&gt; should.be_error()\n\n       elementary.acos(-1.1)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.acos\ngleam_community/maths/elementary acos","url":"gleam_community/maths/elementary.html#acos"},{"doc":"gleam_community/maths/elementary","title":"acosh","content":"pub fn acosh(x: Float) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The inverse hyperbolic cosine function:\n\n \\\\[\n \\forall x \\in [1, +\\infty\\),   \\\\; \\cosh^{-1}{(x)} = y \\in \\[0, +\\infty\\)\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\[1, +\\infty\\)$$ as input and returns\n a numeric value $$y$$ that lies in the range $$\\[0, +\\infty\\)$$ (an angle in radians).\n If the input value is outside the domain of the function an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.acosh(1.0)\n       |&gt; should.equal(Ok(0.0))\n\n       elementary.acosh(0.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.acosh\ngleam_community/maths/elementary acosh","url":"gleam_community/maths/elementary.html#acosh"},{"doc":"gleam_community/maths/elementary","title":"asin","content":"pub fn asin(x: Float) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The inverse sine function:\n\n \\\\[\n \\forall x \\in \\[-1, 1\\],   \\\\; \\sin^{-1}{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\[-1, 1\\]$$ as input and returns a numeric\n value $$y$$ that lies in the range $$\\[-\\frac{\\pi}{2}, \\frac{\\pi}{2}\\]$$ (an angle in radians).\n If the input value is outside the domain of the function an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.asin(0.0)\n       |&gt; should.equal(Ok(0.0))\n\n       elementary.asin(1.1)\n       |&gt; should.be_error()\n\n       elementary.asin(-1.1)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.asin\ngleam_community/maths/elementary asin","url":"gleam_community/maths/elementary.html#asin"},{"doc":"gleam_community/maths/elementary","title":"asinh","content":"pub fn asinh(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The inverse hyperbolic sine function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, \\infty\\),   \\\\; \\sinh^{-1}{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\(-\\infty, +\\infty\\)$$ as input and returns\n a numeric value $$y$$ that lies in the range $$\\(-\\infty, +\\infty\\)$$ (an angle in radians).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.asinh(0.0)\n       |&gt; should.equal(0.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.asinh\ngleam_community/maths/elementary asinh","url":"gleam_community/maths/elementary.html#asinh"},{"doc":"gleam_community/maths/elementary","title":"atan","content":"pub fn atan(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The inverse tangent function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, \\infty\\),   \\\\; \\tan^{-1}{(x)} = y \\in \\[-\\frac{\\pi}{2}, \\frac{\\pi}{2}\\]\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\(-\\infty, +\\infty\\)$$ as input and returns\n a numeric value $$y$$ that lies in the range $$\\[-\\frac{\\pi}{2}, \\frac{\\pi}{2}\\]$$ (an angle in radians).\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.atan(0.0)\n       |&gt; should.equal(0.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.atan\ngleam_community/maths/elementary atan","url":"gleam_community/maths/elementary.html#atan"},{"doc":"gleam_community/maths/elementary","title":"atan2","content":"pub fn atan2(y: Float, x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The inverse 2-argument tangent function:\n\n \\\\[\n \\text{atan2}(y, x) =\n \\begin{cases}\n  \\tan^{-1}(\\frac y x) &amp;\\text{if } x &gt; 0, \\\\\\\\\n  \\tan^{-1}(\\frac y x) + \\pi &amp;\\text{if } x &lt; 0 \\text{ and } y \\ge 0, \\\\\\\\\n  \\tan^{-1}(\\frac y x) - \\pi &amp;\\text{if } x &lt; 0 \\text{ and } y &lt; 0, \\\\\\\\\n  +\\frac{\\pi}{2} &amp;\\text{if } x = 0 \\text{ and } y &gt; 0, \\\\\\\\\n  -\\frac{\\pi}{2} &amp;\\text{if } x = 0 \\text{ and } y &lt; 0, \\\\\\\\\n  \\text{undefined} &amp;\\text{if } x = 0 \\text{ and } y = 0.\n \\end{cases}\n \\\\]\n\n The function returns the angle in radians from the x-axis to the line containing the\n origin $$\\(0, 0\\)$$ and a point given as input with coordinates $$\\(x, y\\)$$. The numeric value\n returned by $$\\text{atan2}(y, x)$$ is in the range $$\\[-\\pi, \\pi\\]$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.atan2(0.0, 0.0)\n       |&gt; should.equal(0.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.atan2\ngleam_community/maths/elementary atan2","url":"gleam_community/maths/elementary.html#atan2"},{"doc":"gleam_community/maths/elementary","title":"atanh","content":"pub fn atanh(x: Float) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The inverse hyperbolic tangent function:\n\n \\\\[\n \\forall x \\in \\(-1, 1\\),   \\\\; \\tanh^{-1}{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\(-1, 1\\)$$ as input and returns\n a numeric value $$y$$ that lies in the range $$\\(-\\infty, \\infty\\)$$ (an angle in radians).\n If the input value is outside the domain of the function an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.atanh(0.0)\n       |&gt; should.equal(Ok(0.0))\n\n       elementary.atanh(1.0)\n       |&gt; should.be_error()\n\n       elementary.atanh(-1.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.atanh\ngleam_community/maths/elementary atanh","url":"gleam_community/maths/elementary.html#atanh"},{"doc":"gleam_community/maths/elementary","title":"cos","content":"pub fn cos(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The cosine function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, +\\infty\\),   \\\\; \\cos{(x)} = y \\in \\[-1, 1\\]\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\(-\\infty, \\infty\\)$$ (an angle in radians)\n as input and returns a numeric value $$y$$ that lies in the range $$\\[-1, 1\\]$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.cos(0.0)\n       |&gt; should.equal(1.0)\n\n       elementary.cos(elementary.pi())\n       |&gt; should.equal(-1.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.cos\ngleam_community/maths/elementary cos","url":"gleam_community/maths/elementary.html#cos"},{"doc":"gleam_community/maths/elementary","title":"cosh","content":"pub fn cosh(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The hyperbolic cosine function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, \\infty\\),   \\\\; \\cosh{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\(-\\infty, \\infty\\)$$ as input (an angle in radians)\n and returns a numeric value $$y$$ that lies in the range $$\\(-\\infty, \\infty\\)$$.\n If the input value is too large an overflow error might occur.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.cosh(0.0)\n       |&gt; should.equal(0.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.cosh\ngleam_community/maths/elementary cosh","url":"gleam_community/maths/elementary.html#cosh"},{"doc":"gleam_community/maths/elementary","title":"cube_root","content":"pub fn cube_root(x: Float) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The cube root function: $$y = \\sqrt[3]{x} = x^{\\frac{1}{3}}$$.\n\n Note that the function is not defined if:\n 1. The input is negative ($$x &lt; 0$$). An error will be returned\n    as an imaginary number will otherwise have to be returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.cube_root(1.0)\n       |&gt; should.equal(Ok(1.0))\n\n       elementary.cube_root(27.0)\n       |&gt; should.equal(Ok(3.0))\n\n       elementary.cube_root(-1.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.cube_root\ngleam_community/maths/elementary cube_root","url":"gleam_community/maths/elementary.html#cube_root"},{"doc":"gleam_community/maths/elementary","title":"e","content":"pub fn e() -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Euler&#39;s number $$e \\approx 2.71828\\dots$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       // Test that the constant is approximately equal to 2.7128...\n       elementary.e()\n       |&gt; elementary.is_close(2.7128, 0.0, 0.000001)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.e\ngleam_community/maths/elementary e","url":"gleam_community/maths/elementary.html#e"},{"doc":"gleam_community/maths/elementary","title":"exponential","content":"pub fn exponential(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The exponential function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, \\infty\\),   \\\\; e^{(x)} = y \\in \\(0, +\\infty\\)\n \\\\]\n\n $$e \\approx 2.71828\\dots$$ is Eulers&#39; number.\n\n Note: If the input value $$x$$ is too large an overflow error might occur.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.exponential(0.0)\n       |&gt; should.equal(1.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.exponential\ngleam_community/maths/elementary exponential","url":"gleam_community/maths/elementary.html#exponential"},{"doc":"gleam_community/maths/elementary","title":"logarithm","content":"pub fn logarithm(\n  x: Float,\n  base: Option(Float),\n) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The base $$b$$ logarithm function (computed through the &quot;change of base&quot; formula):\n\n \\\\[\n \\forall x \\in \\(0, \\infty\\) \\textnormal{ and } b &gt; 1,  \\\\; \\log_{b}{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\(0, \\infty\\)$$ and a base $$b &gt; 1$$ as input and returns\n a numeric value $$y$$ that lies in the range $$\\(-\\infty, \\infty\\)$$.\n If the input value is outside the domain of the function an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/option\n     import gleam_community/maths/elementary\n\n     pub fn example () {\n       elementary.logarithm(1.0, option.Some(10.0))\n       |&gt; should.equal(Ok(0.0))\n\n       elementary.logarithm(elementary.e(), option.Some(elementary.e()))\n       |&gt; should.equal(Ok(1.0))\n\n       elementary.logarithm(-1.0, option.Some(2.0))\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.logarithm\ngleam_community/maths/elementary logarithm","url":"gleam_community/maths/elementary.html#logarithm"},{"doc":"gleam_community/maths/elementary","title":"logarithm_10","content":"pub fn logarithm_10(x: Float) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The base-10 logarithm function:\n\n \\\\[\n \\forall x \\in \\(0, \\infty),   \\\\; \\log_{10}{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\(0, \\infty\\)$$ as input and returns\n a numeric value $$y$$ that lies in the range $$\\(-\\infty, \\infty\\)$$.\n If the input value is outside the domain of the function an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example () {\n       elementary.logarithm_10(1.0)\n       |&gt; should.equal(Ok(0.0))\n\n       elementary.logarithm_10(10.0)\n       |&gt; should.equal(Ok(1.0))\n\n       elementary.logarithm_10(-1.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.logarithm_10\ngleam_community/maths/elementary logarithm_10","url":"gleam_community/maths/elementary.html#logarithm_10"},{"doc":"gleam_community/maths/elementary","title":"logarithm_2","content":"pub fn logarithm_2(x: Float) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The The base-2 logarithm function:\n\n \\\\[\n \\forall x \\in \\(0, \\infty),   \\\\; \\log_{2}{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\(0, \\infty\\)$$ as input and returns\n a numeric value $$y$$ that lies in the range $$\\(-\\infty, \\infty\\)$$.\n If the input value is outside the domain of the function an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example () {\n       elementary.logarithm_2(1.0)\n       |&gt; should.equal(Ok(0.0))\n\n       elementary.logarithm_2(2.0)\n       |&gt; should.equal(Ok(1.0))\n\n       elementary.logarithm_2(-1.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.logarithm_2\ngleam_community/maths/elementary logarithm_2","url":"gleam_community/maths/elementary.html#logarithm_2"},{"doc":"gleam_community/maths/elementary","title":"natural_logarithm","content":"pub fn natural_logarithm(x: Float) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The natural logarithm function:\n\n \\\\[\n \\forall x \\in \\(0, \\infty\\),   \\\\; \\log_{e}{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\(0, \\infty\\)$$ as input and returns\n a numeric value $$y$$ that lies in the range $$\\(-\\infty, \\infty\\)$$.\n If the input value is outside the domain of the function an error is returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example () {\n       elementary.natural_logarithm(1.0)\n       |&gt; should.equal(Ok(0.0))\n\n       elementary.natural_logarithm(elementary.e())\n       |&gt; should.equal(Ok(1.0))\n\n       elementary.natural_logarithm(-1.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.natural_logarithm\ngleam_community/maths/elementary natural_logarithm","url":"gleam_community/maths/elementary.html#natural_logarithm"},{"doc":"gleam_community/maths/elementary","title":"nth_root","content":"pub fn nth_root(x: Float, n: Int) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The $$n$$&#39;th root function: $$y = \\sqrt[n]{x} = x^{\\frac{1}{n}}$$.\n\n Note that the function is not defined if:\n 1. The input is negative ($$x &lt; 0$$). An error will be returned\n    as an imaginary number will otherwise have to be returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.nth_root(1.0, 2)\n       |&gt; should.equal(Ok(1.0))\n\n       elementary.nth_root(27.0, 3)\n       |&gt; should.equal(Ok(3.0))\n\n       elementary.nth_root(256.0, 4)\n       |&gt; should.equal(Ok(4.0))\n\n       elementary.nth_root(-1.0, 2)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.nth_root\ngleam_community/maths/elementary nth_root","url":"gleam_community/maths/elementary.html#nth_root"},{"doc":"gleam_community/maths/elementary","title":"pi","content":"pub fn pi() -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The mathematical constant pi: $$\\pi \\approx 3.1415\\dots$$\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.pi\ngleam_community/maths/elementary pi","url":"gleam_community/maths/elementary.html#pi"},{"doc":"gleam_community/maths/elementary","title":"power","content":"pub fn power(x: Float, y: Float) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The exponentiation function: $$y = x^{a}$$.\n\n Note that the function is not defined if:\n 1. The base is negative ($$x &lt; 0$$) and the exponent is fractional\n    ($$a = \\frac{n}{m}$$ is an irrreducible fraction). An error will be returned\n    as an imaginary number will otherwise have to be returned.\n 2. The base is zero ($$x = 0$$) and the exponent is negative ($$a &lt; 0$$) then the\n    expression is equivalent to the exponent $$y$$ divided by $$0$$ and an\n    error will have to be returned as the expression is otherwise undefined.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.power(2., -1.)\n       |&gt; should.equal(Ok(0.5))\n\n       elementary.power(2., 2.)\n       |&gt; should.equal(Ok(4.0))\n\n       elementary.power(-1., 0.5)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.power\ngleam_community/maths/elementary power","url":"gleam_community/maths/elementary.html#power"},{"doc":"gleam_community/maths/elementary","title":"sin","content":"pub fn sin(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The sine function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, +\\infty\\),   \\\\; \\sin{(x)} = y \\in \\[-1, 1\\]\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\(-\\infty, \\infty\\)$$ (an angle in radians)\n as input and returns a numeric value $$y$$ that lies in the range $$\\[-1, 1\\]$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.sin(0.0)\n       |&gt; should.equal(0.0)\n\n       elementary.sin(0.5 *. elementary.pi())\n       |&gt; should.equal(1.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.sin\ngleam_community/maths/elementary sin","url":"gleam_community/maths/elementary.html#sin"},{"doc":"gleam_community/maths/elementary","title":"sinh","content":"pub fn sinh(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The hyperbolic sine function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, +\\infty\\),   \\\\; \\sinh{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\(-\\infty, +\\infty\\)$$ as input\n (an angle in radians) and returns a numeric value $$y$$ that lies in the range\n $$\\(-\\infty, +\\infty\\)$$. If the input value is too large an overflow error might\n occur.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.sinh(0.0)\n       |&gt; should.equal(0.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.sinh\ngleam_community/maths/elementary sinh","url":"gleam_community/maths/elementary.html#sinh"},{"doc":"gleam_community/maths/elementary","title":"square_root","content":"pub fn square_root(x: Float) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The square root function: $$y = \\sqrt[2]{x} = x^{\\frac{1}{2}}$$.\n\n Note that the function is not defined if:\n 1. The input is negative ($$x &lt; 0$$). An error will be returned\n    as an imaginary number will otherwise have to be returned.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.square_root(1.0)\n       |&gt; should.equal(Ok(1.0))\n\n       elementary.square_root(4.0)\n       |&gt; should.equal(Ok(2.0))\n\n       elementary.square_root(-1.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.square_root\ngleam_community/maths/elementary square_root","url":"gleam_community/maths/elementary.html#square_root"},{"doc":"gleam_community/maths/elementary","title":"tan","content":"pub fn tan(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The tangent function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, +\\infty\\),   \\\\; \\tan{(x)} = y \\in \\(-\\infty, +\\infty\\)\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\(-\\infty, +\\infty\\)$$ as input\n (an angle in radians) and returns a numeric value $$y$$ that lies in the range\n $$\\(-\\infty, +\\infty\\)$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       elementary.tan(0.0)\n       |&gt; should.equal(0.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.tan\ngleam_community/maths/elementary tan","url":"gleam_community/maths/elementary.html#tan"},{"doc":"gleam_community/maths/elementary","title":"tanh","content":"pub fn tanh(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The hyperbolic tangent function:\n\n \\\\[\n \\forall x \\in \\(-\\infty, \\infty\\),   \\\\; \\tanh{(x)} = y \\in \\[-1, 1\\]\n \\\\]\n\n The function takes a number $$x$$ in its domain $$\\(-\\infty, \\infty\\)$$ as input (an angle in radians)\n and returns a numeric value $$y$$ that lies in the range $$\\[-1, 1\\]$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n\n     pub fn example () {\n       elementary.tanh(0.0)\n       |&gt; should.equal(0.0)\n\n       elementary.tanh(25.0)\n       |&gt; should.equal(1.0)\n\n       elementary.tanh(-25.0)\n       |&gt; should.equal(-1.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.tanh\ngleam_community/maths/elementary tanh","url":"gleam_community/maths/elementary.html#tanh"},{"doc":"gleam_community/maths/elementary","title":"tau","content":"pub fn tau() -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The mathematical constant tau: $$\\tau = 2 \\cdot \\pi \\approx 6.283\\dots$$\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/elementary.tau\ngleam_community/maths/elementary tau","url":"gleam_community/maths/elementary.html#tau"},{"doc":"gleam_community/maths/elementary","title":"gleam_community/maths/elementary","content":"&lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.css&quot; integrity=&quot;sha384-GvrOXuhMATgEsSwCs4smul74iXGOixntILdUW9XmUC6+HX0sLNAK3q71HotJqlAn&quot; crossorigin=&quot;anonymous&quot;&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.js&quot; integrity=&quot;sha384-cpW21h6RZv/phavutF+AuVYrr+dA8xD9zs6FwLpaCct6O9ctzYFfFr4dgmgccOTx&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/contrib/auto-render.min.js&quot; integrity=&quot;sha384-+VBxd3r6XgURycqtZ117nYw44OOcIax56Z4dCRWbxyPt0Koah1uHoK0o4+/RRE05&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script&gt;\n    document.addEventListener(&quot;DOMContentLoaded&quot;, function() {\n        renderMathInElement(document.body, {\n          // customised options\n          // • auto-render specific keys, e.g.:\n          delimiters: [\n              {left: &#39;$$&#39;, right: &#39;$$&#39;, display: false},\n            //   {left: &#39;$&#39;, right: &#39;$&#39;, display: false},\n            //   {left: &#39;\\\\(&#39;, right: &#39;\\\\)&#39;, display: false},\n              {left: &#39;\\\\[&#39;, right: &#39;\\\\]&#39;, display: true}\n          ],\n          // • rendering keys, e.g.:\n          throwOnError : false\n        });\n    });\n&lt;/script&gt;\n&lt;style&gt;\n    .katex { font-size: 1.1em; }\n&lt;/style&gt;\n \n ---\n \n Elementary: A module containing a comprehensive set of foundational mathematical functions and constants.\n \n * **Trigonometric and hyperbolic functions**\n   * [`acos`](#acos)\n   * [`acosh`](#acosh)\n   * [`asin`](#asin)\n   * [`asinh`](#asinh)\n   * [`atan`](#atan)\n   * [`atan2`](#atan2)\n   * [`atanh`](#atanh)\n   * [`cos`](#cos)\n   * [`cosh`](#cosh)\n   * [`sin`](#sin)\n   * [`sinh`](#sinh)\n   * [`tan`](#tan)\n   * [`tanh`](#tanh)\n * **Powers, logs and roots**\n   * [`exponential`](#exponential)\n   * [`natural_logarithm`](#natural_logarithm)\n   * [`logarithm`](#logarithm)\n   * [`logarithm_2`](#logarithm_2)\n   * [`logarithm_10`](#logarithm_10)\n   * [`power`](#power)\n   * [`square_root`](#square_root)\n   * [`cube_root`](#cube_root)\n   * [`nth_root`](#nth_root)\n * **Mathematical constants**\n   * [`pi`](#pi)\n   * [`tau`](#tau)\n   * [`e`](#e)\n ","url":"gleam_community/maths/elementary.html"},{"doc":"gleam_community/maths/conversion","title":"degrees_to_radians","content":"pub fn degrees_to_radians(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Convert a value in degrees to a value measured in radians.\n That is, $$1 \\text{ degrees } = \\frac{\\pi}{180} \\text{ radians }$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/conversion\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       conversion.degrees_to_radians(360.)\n       |&gt; should.equal(2. *. elementary.pi())\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/conversion.degrees_to_radians\ngleam_community/maths/conversion degrees_to_radians","url":"gleam_community/maths/conversion.html#degrees_to_radians"},{"doc":"gleam_community/maths/conversion","title":"float_to_int","content":"pub fn float_to_int(x: Float) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function returns the integral part of a given floating point value.\n That is, everything after the decimal point of a given floating point value is discarded and only the integer value before the decimal point is returned. \n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/option\n     import gleam_community/maths/conversion\n     import gleam_community/maths/piecewise\n\n     pub fn example() {\n       conversion.float_to_int(12.0654)\n       |&gt; should.equal(12)\n       \n       // Note: Making the following function call is equivalent\n       // but instead of returning a value of type &#39;Int&#39; a value\n       // of type &#39;Float&#39; is returned.\n       piecewise.round(12.0654, option.Some(0), option.Some(piecewise.RoundToZero))\n       |&gt; should.equal(Ok(12.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/conversion.float_to_int\ngleam_community/maths/conversion float_to_int","url":"gleam_community/maths/conversion.html#float_to_int"},{"doc":"gleam_community/maths/conversion","title":"int_to_float","content":"pub fn int_to_float(x: Int) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A function that produces a number of type `Float` from an `Int`.\n \n Note: The function is equivalent to the `int.to_float` function in the Gleam stdlib.\n \n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/conversion\n\n     pub fn example() {\n       conversion.int_to_float(-1)\n       |&gt; should.equal(-1.0)\n     \n       conversion.int_to_float(1)\n       |&gt; should.equal(1.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/conversion.int_to_float\ngleam_community/maths/conversion int_to_float","url":"gleam_community/maths/conversion.html#int_to_float"},{"doc":"gleam_community/maths/conversion","title":"radians_to_degrees","content":"pub fn radians_to_degrees(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Convert a value in degrees to a value measured in radians.\n That is, $$1 \\text{ radians } = \\frac{180}{\\pi} \\text{ degrees }$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/conversion\n     import gleam_community/maths/elementary\n\n     pub fn example() {\n       conversion.radians_to_degrees(0.0)\n       |&gt; should.equal(0.0)\n\n       conversion.radians_to_degrees(2. *. elementary.pi())\n       |&gt; should.equal(360.)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/conversion.radians_to_degrees\ngleam_community/maths/conversion radians_to_degrees","url":"gleam_community/maths/conversion.html#radians_to_degrees"},{"doc":"gleam_community/maths/conversion","title":"gleam_community/maths/conversion","content":"&lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.css&quot; integrity=&quot;sha384-GvrOXuhMATgEsSwCs4smul74iXGOixntILdUW9XmUC6+HX0sLNAK3q71HotJqlAn&quot; crossorigin=&quot;anonymous&quot;&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.js&quot; integrity=&quot;sha384-cpW21h6RZv/phavutF+AuVYrr+dA8xD9zs6FwLpaCct6O9ctzYFfFr4dgmgccOTx&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/contrib/auto-render.min.js&quot; integrity=&quot;sha384-+VBxd3r6XgURycqtZ117nYw44OOcIax56Z4dCRWbxyPt0Koah1uHoK0o4+/RRE05&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script&gt;\n    document.addEventListener(&quot;DOMContentLoaded&quot;, function() {\n        renderMathInElement(document.body, {\n          // customised options\n          // • auto-render specific keys, e.g.:\n          delimiters: [\n              {left: &#39;$$&#39;, right: &#39;$$&#39;, display: false},\n            //   {left: &#39;$&#39;, right: &#39;$&#39;, display: false},\n            //   {left: &#39;\\\\(&#39;, right: &#39;\\\\)&#39;, display: false},\n              {left: &#39;\\\\[&#39;, right: &#39;\\\\]&#39;, display: true}\n          ],\n          // • rendering keys, e.g.:\n          throwOnError : false\n        });\n    });\n&lt;/script&gt;\n&lt;style&gt;\n    .katex { font-size: 1.1em; }\n&lt;/style&gt;\n \n ---\n \n Conversion: A module containing various functions for converting between types and quantities.\n \n * **Misc. functions**\n   * [`float_to_int`](#float_to_int)\n   * [`int_to_float`](#int_to_float)\n   * [`degrees_to_radians`](#degrees_to_radians)\n   * [`radians_to_degrees`](#radians_to_degrees)","url":"gleam_community/maths/conversion.html"},{"doc":"gleam_community/maths/piecewise","title":"RoundingMode","content":"pub type RoundingMode {\n  RoundNearest\n  RoundTiesAway\n  RoundTiesUp\n  RoundToZero\n  RoundDown\n  RoundUp\n}\n\nRoundNearest\n\n\nRoundTiesAway\n\n\nRoundTiesUp\n\n\nRoundToZero\n\n\nRoundDown\n\n\nRoundUp\n\n\nSynonyms:\ngleam_community/maths/piecewise.RoundingMode\ngleam_community/maths/piecewise RoundingMode","url":"gleam_community/maths/piecewise.html#RoundingMode"},{"doc":"gleam_community/maths/piecewise","title":"arg_maximum","content":"pub fn arg_maximum(\n  arr: List(a),\n  compare: fn(a, a) -&gt; Order,\n) -&gt; Result(List(Int), String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Returns the indices of the maximum values in a given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/float\n     import gleam_community/maths/piecewise\n\n     pub fn example () {\n       // An empty lists returns an error\n       []\n       |&gt; piecewise.arg_maximum(float.compare)\n       |&gt; should.be_error()\n     \n       // Valid input returns a result\n       [4.0, 4.0, 3.0, 2.0, 1.0]\n       |&gt; piecewise.arg_maximum(float.compare)\n       |&gt; should.equal(Ok([0, 1]))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.arg_maximum\ngleam_community/maths/piecewise arg_maximum","url":"gleam_community/maths/piecewise.html#arg_maximum"},{"doc":"gleam_community/maths/piecewise","title":"arg_minimum","content":"pub fn arg_minimum(\n  arr: List(a),\n  compare: fn(a, a) -&gt; Order,\n) -&gt; Result(List(Int), String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Returns the indices of the minimum values in a given list. \n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/float\n     import gleam_community/maths/piecewise\n\n     pub fn example () {\n       // An empty lists returns an error\n       []\n       |&gt; piecewise.arg_minimum(float.compare)\n       |&gt; should.be_error()\n     \n       // Valid input returns a result\n       [4.0, 4.0, 3.0, 2.0, 1.0]\n       |&gt; piecewise.arg_minimum(float.compare)\n       |&gt; should.equal(Ok([4]))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.arg_minimum\ngleam_community/maths/piecewise arg_minimum","url":"gleam_community/maths/piecewise.html#arg_minimum"},{"doc":"gleam_community/maths/piecewise","title":"ceiling","content":"pub fn ceiling(\n  x: Float,\n  digits: Option(Int),\n) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The ceiling function rounds a given input value $$x \\in \\mathbb{R}$$ to the nearest integer value (at the specified digit) that is larger than or equal to the input $$x$$. \n\n Note: The ceiling function is used as an alias for the rounding function [`round`](#round) with rounding mode `RoundUp`.\n\n &lt;details&gt;\n     &lt;summary&gt;Details&lt;/summary&gt;\n\n   For example, $$12.0654$$ is rounded to:\n   - $$13.0$$ for 0 digits after the decimal point (`digits = 0`)\n   - $$12.1$$ for 1 digit after the decimal point (`digits = 1`)\n   - $$12.07$$ for 2 digits after the decimal point (`digits = 2`)\n   - $$12.066$$ for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative number refers to the digits before the decimal point.\n   For example, $$12.0654$$ is rounded to:\n   - $$20.0$$ for 1 digit places before the decimal point (`digit = -1`)\n   - $$100.0$$ for 2 digits before the decimal point (`digits = -2`)\n   - $$1000.0$$ for 3 digits before the decimal point (`digits = -3`)\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/option\n     import gleam_community/maths/piecewise\n\n     pub fn example() {\n       piecewise.ceiling(12.0654, option.Some(1))\n       |&gt; should.equal(Ok(12.1))\n\n       piecewise.ceiling(12.0654, option.Some(2))\n       |&gt; should.equal(Ok(12.07))\n\n       piecewise.ceiling(12.0654, option.Some(3))\n       |&gt; should.equal(Ok(12.066))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.ceiling\ngleam_community/maths/piecewise ceiling","url":"gleam_community/maths/piecewise.html#ceiling"},{"doc":"gleam_community/maths/piecewise","title":"extrema","content":"pub fn extrema(\n  arr: List(a),\n  compare: fn(a, a) -&gt; Order,\n) -&gt; Result(#(a, a), String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Returns a tuple consisting of the minimum and maximum values of a given list. \n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/float\n     import gleam_community/maths/piecewise\n\n     pub fn example () {\n       // An empty lists returns an error\n       []\n       |&gt; piecewise.extrema(float.compare)\n       |&gt; should.be_error()\n     \n       // Valid input returns a result\n       [4.0, 4.0, 3.0, 2.0, 1.0]\n       |&gt; piecewise.extrema(float.compare)\n       |&gt; should.equal(Ok(#(1.0, 4.0)))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.extrema\ngleam_community/maths/piecewise extrema","url":"gleam_community/maths/piecewise.html#extrema"},{"doc":"gleam_community/maths/piecewise","title":"float_absolute_difference","content":"pub fn float_absolute_difference(a: Float, b: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The absolute difference:\n\n \\\\[\n  \\forall x, y \\in \\mathbb{R}, \\\\; |x - y|  \\in \\mathbb{R}_{+}. \n \\\\]\n\n The function takes two inputs $$x$$ and $$y$$ and returns a positive float\n value which is the the absolute difference of the inputs.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/piecewise\n\n     pub fn example() {\n       piecewise.float_absolute_difference(-10.0, 10.0)\n       |&gt; should.equal(20.0)\n\n       piecewise.float_absolute_difference(0.0, -2.0)\n       |&gt; should.equal(2.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.float_absolute_difference\ngleam_community/maths/piecewise float_absolute_difference","url":"gleam_community/maths/piecewise.html#float_absolute_difference"},{"doc":"gleam_community/maths/piecewise","title":"float_absolute_value","content":"pub fn float_absolute_value(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The absolute value:\n\n \\\\[\n  \\forall x, y \\in \\mathbb{R}, \\\\; |x|  \\in \\mathbb{R}_{+}. \n \\\\]\n\n The function takes an input $$x$$ and returns a positive float value.\n\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.float_absolute_value\ngleam_community/maths/piecewise float_absolute_value","url":"gleam_community/maths/piecewise.html#float_absolute_value"},{"doc":"gleam_community/maths/piecewise","title":"float_copy_sign","content":"pub fn float_copy_sign(x: Float, y: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function takes two arguments $$x, y \\in \\mathbb{R}$$ and returns $$x$$ such that it has the same sign as $$y$$.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.float_copy_sign\ngleam_community/maths/piecewise float_copy_sign","url":"gleam_community/maths/piecewise.html#float_copy_sign"},{"doc":"gleam_community/maths/piecewise","title":"float_flip_sign","content":"pub fn float_flip_sign(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function flips the sign of a given input value $$x \\in \\mathbb{R}$$.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.float_flip_sign\ngleam_community/maths/piecewise float_flip_sign","url":"gleam_community/maths/piecewise.html#float_flip_sign"},{"doc":"gleam_community/maths/piecewise","title":"float_sign","content":"pub fn float_sign(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function takes an input $$x \\in \\mathbb{R}$$ and returns the sign of\n the input, indicating whether it is positive (+1.0), negative (-1.0), or \n zero (0.0).\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.float_sign\ngleam_community/maths/piecewise float_sign","url":"gleam_community/maths/piecewise.html#float_sign"},{"doc":"gleam_community/maths/piecewise","title":"floor","content":"pub fn floor(\n  x: Float,\n  digits: Option(Int),\n) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The floor function rounds input $$x \\in \\mathbb{R}$$ to the nearest integer value (at the specified digit) that is less than or equal to the input $$x$$.\n\n Note: The floor function is used as an alias for the rounding function [`round`](#round) with rounding mode `RoundDown`.\n\n &lt;details&gt;\n     &lt;summary&gt;Details&lt;/summary&gt;\n\n   For example, $$12.0654$$ is rounded to:\n   - $$12.0$$ for 0 digits after the decimal point (`digits = 0`)\n   - $$12.0$$ for 1 digits after the decimal point (`digits = 1`)\n   - $$12.06$$ for 2 digits after the decimal point (`digits = 2`)\n   - $$12.065$$ for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative number refers to the digits before the decimal point.\n   - $$10.0$$ for 1 digit before the decimal point (`digits = -1`)\n   - $$0.0$$ for 2 digits before the decimal point (`digits = -2`)\n   - $$0.0$$ for 3 digits before the decimal point (`digits = -3`)\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/option\n     import gleam_community/maths/piecewise\n\n     pub fn example() {\n       piecewise.floor(12.0654, option.Some(1))\n       |&gt; should.equal(Ok(12.0))\n\n       piecewise.floor(12.0654, option.Some(2))\n       |&gt; should.equal(Ok(12.06))\n\n       piecewise.floor(12.0654, option.Some(3))\n       |&gt; should.equal(Ok(12.065))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.floor\ngleam_community/maths/piecewise floor","url":"gleam_community/maths/piecewise.html#floor"},{"doc":"gleam_community/maths/piecewise","title":"int_absolute_difference","content":"pub fn int_absolute_difference(a: Int, b: Int) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The absolute difference:\n\n \\\\[\n  \\forall x, y \\in \\mathbb{Z}, \\\\; |x - y|  \\in \\mathbb{Z}_{+}. \n \\\\]\n\n The function takes two inputs $$x$$ and $$y$$ and returns a positive integer value which is the the absolute difference of the inputs.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/piecewise\n\n     pub fn example() {\n       piecewise.absolute_difference(-10, 10)\n       |&gt; should.equal(20)\n\n       piecewise.absolute_difference(0, -2)\n       |&gt; should.equal(2)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.int_absolute_difference\ngleam_community/maths/piecewise int_absolute_difference","url":"gleam_community/maths/piecewise.html#int_absolute_difference"},{"doc":"gleam_community/maths/piecewise","title":"int_absolute_value","content":"pub fn int_absolute_value(x: Int) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The absolute value:\n\n \\\\[\n  \\forall x, y \\in \\mathbb{Z}, \\\\; |x|  \\in \\mathbb{Z}_{+}. \n \\\\]\n\n The function takes an input $$x$$ and returns a positive integer value.\n\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.int_absolute_value\ngleam_community/maths/piecewise int_absolute_value","url":"gleam_community/maths/piecewise.html#int_absolute_value"},{"doc":"gleam_community/maths/piecewise","title":"int_copy_sign","content":"pub fn int_copy_sign(x: Int, y: Int) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function takes two arguments $$x, y \\in \\mathbb{Z}$$ and returns $$x$$ such that it has the same sign as $$y$$.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.int_copy_sign\ngleam_community/maths/piecewise int_copy_sign","url":"gleam_community/maths/piecewise.html#int_copy_sign"},{"doc":"gleam_community/maths/piecewise","title":"int_flip_sign","content":"pub fn int_flip_sign(x: Int) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function flips the sign of a given input value $$x \\in \\mathbb{Z}$$.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.int_flip_sign\ngleam_community/maths/piecewise int_flip_sign","url":"gleam_community/maths/piecewise.html#int_flip_sign"},{"doc":"gleam_community/maths/piecewise","title":"int_sign","content":"pub fn int_sign(x: Int) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function takes an input $$x \\in \\mathbb{Z}$$ and returns the sign of\n the input, indicating whether it is positive (+1), negative (-1), or zero\n (0).\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.int_sign\ngleam_community/maths/piecewise int_sign","url":"gleam_community/maths/piecewise.html#int_sign"},{"doc":"gleam_community/maths/piecewise","title":"list_maximum","content":"pub fn list_maximum(\n  arr: List(a),\n  compare: fn(a, a) -&gt; Order,\n) -&gt; Result(a, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Returns the maximum value of a given list. \n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/float\n     import gleam_community/maths/piecewise\n\n     pub fn example () {\n       // An empty lists returns an error\n       []\n       |&gt; piecewise.list_maximum(float.compare)\n       |&gt; should.be_error()\n\n       // Valid input returns a result\n       [4.0, 4.0, 3.0, 2.0, 1.0]\n       |&gt; piecewise.list_maximum(float.compare)\n       |&gt; should.equal(Ok(4.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.list_maximum\ngleam_community/maths/piecewise list_maximum","url":"gleam_community/maths/piecewise.html#list_maximum"},{"doc":"gleam_community/maths/piecewise","title":"list_minimum","content":"pub fn list_minimum(\n  arr: List(a),\n  compare: fn(a, a) -&gt; Order,\n) -&gt; Result(a, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Returns the minimum value of a given list. \n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/int\n     import gleam_community/maths/piecewise\n\n     pub fn example () {\n       // An empty lists returns an error\n       []\n       |&gt; piecewise.list_minimum(int.compare)\n       |&gt; should.be_error()\n     \n       // Valid input returns a result\n       [4, 4, 3, 2, 1]\n       |&gt; piecewise.list_minimum(int.compare)\n       |&gt; should.equal(Ok(1))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\nSynonyms:\ngleam_community/maths/piecewise.list_minimum\ngleam_community/maths/piecewise list_minimum","url":"gleam_community/maths/piecewise.html#list_minimum"},{"doc":"gleam_community/maths/piecewise","title":"maximum","content":"pub fn maximum(x: a, y: a, compare: fn(a, a) -&gt; Order) -&gt; a\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The maximum function takes two arguments $$x, y$$ along with a function\n for comparing $$x, y$$. The function returns the largest of the two given\n values.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/float\n     import gleam_community/maths/piecewise\n\n     pub fn example() {\n       piecewise.maximum(2.0, 1.5, float.compare)\n       |&gt; should.equal(1.5)\n\n       piecewise.maximum(1.5, 2.0, float.compare)\n       |&gt; should.equal(1.5)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.maximum\ngleam_community/maths/piecewise maximum","url":"gleam_community/maths/piecewise.html#maximum"},{"doc":"gleam_community/maths/piecewise","title":"minimum","content":"pub fn minimum(x: a, y: a, compare: fn(a, a) -&gt; Order) -&gt; a\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The minimum function takes two arguments $$x, y$$ along with a function\n for comparing $$x, y$$. The function returns the smallest of the two given\n values.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/float\n     import gleam_community/maths/piecewise\n\n     pub fn example() {\n       piecewise.minimum(2.0, 1.5, float.compare)\n       |&gt; should.equal(1.5)\n\n       piecewise.minimum(1.5, 2.0, float.compare)\n       |&gt; should.equal(1.5)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.minimum\ngleam_community/maths/piecewise minimum","url":"gleam_community/maths/piecewise.html#minimum"},{"doc":"gleam_community/maths/piecewise","title":"minmax","content":"pub fn minmax(x: a, y: a, compare: fn(a, a) -&gt; Order) -&gt; #(a, a)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The minmax function takes two arguments $$x, y$$ along with a function\n for comparing $$x, y$$. The function returns a tuple with the smallest \n value first and largest second.\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/float\n     import gleam_community/maths/piecewise\n\n     pub fn example() {\n       piecewise.minmax(2.0, 1.5, float.compare)\n       |&gt; should.equal(#(1.5, 2.0))\n\n       piecewise.minmax(1.5, 2.0, float.compare)\n       |&gt; should.equal(#(1.5, 2.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.minmax\ngleam_community/maths/piecewise minmax","url":"gleam_community/maths/piecewise.html#minmax"},{"doc":"gleam_community/maths/piecewise","title":"round","content":"pub fn round(\n  x: Float,\n  digits: Option(Int),\n  mode: Option(RoundingMode),\n) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function rounds a float to a specific number of digits (after the decimal place or before if negative) using a specified rounding mode.\n\n Valid rounding modes include:\n - `RoundNearest` (default): The input $$x$$ is rounded to the nearest integer value (at the specified digit) with ties (fractional values of 0.5) being rounded to the nearest even integer.\n - `RoundTiesAway`: The input $$x$$ is rounded to the nearest integer value (at the specified digit) with ties (fractional values of 0.5) being rounded away from zero (C/C++ rounding behavior).\n - `RoundTiesUp`: The input $$x$$ is rounded to the nearest integer value (at the specified digit) with ties (fractional values of 0.5) being rounded towards $$+\\infty$$ (Java/JavaScript rounding behaviour).\n - `RoundToZero`: The input $$x$$ is rounded to the nearest integer value (at the specified digit) that is less than or equal to the absolute value of the input $$x$$. An alias for this rounding mode is [`truncate`](#truncate).\n - `RoundDown`: The input $$x$$ is rounded to the nearest integer value (at the specified digit) that is less than or equal to the input $$x$$. An alias for this rounding mode is [`floor`](#floor).\n - `RoundUp`: The input $$x$$ is rounded to the nearest integer value (at the specified digit) that is larger than or equal to the input $$x$$. An alias for this rounding mode is [`ceiling`](#ceiling).\n\n &lt;details&gt;\n &lt;summary&gt;Details&lt;/summary&gt;\n\n   The `RoundNearest` rounding mode, rounds $$12.0654$$ to:\n   - $$12.0$$ for 0 digits after the decimal point (`digits = 0`)\n   - $$12.1$$ for 1 digit after the decimal point (`digits = 1`)\n   - $$12.07$$ for 2 digits after the decimal point (`digits = 2`)\n   - $$12.065$$ for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative number refers to the digits before the decimal point.\n   - $$10.0$$ for 1 digit before the decimal point (`digits = -1`)\n   - $$0.0$$ for 2 digits before the decimal point (`digits = -2`)\n   - $$0.0$$ for 3 digits before the decimal point (`digits = -3`)\n\n   The `RoundTiesAway` rounding mode, rounds $$12.0654$$ to:\n   - $$12.0$$ for 0 digits after the decimal point (`digits = 0`)\n   - $$12.1$$ for 1 digit after the decimal point (`digits = 1`)\n   - $$12.07$$ for 2 digits after the decimal point (`digits = 2`)\n   - $$12.065$$ for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative number refers to the digits before the decimal point.\n   - $$10.0$$ for 1 digit before the decimal point (`digits = -1`)\n   - $$0.0$$ for 2 digits before the decimal point (`digits = -2`)\n   - $$0.0$$ for 3 digits before the decimal point (`digits = -3`)\n\n   The `RoundTiesUp` rounding mode, rounds $$12.0654$$ to:\n   - $$12.0$$ for 0 digits after the decimal point (`digits = 0`)\n   - $$12.1$$ for 1 digits after the decimal point (`digits = 1`)\n   - $$12.07$$ for 2 digits after the decimal point (`digits = 2`)\n   - $$12.065$$ for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative number refers to the digits before the decimal point.\n   - $$10.0$$ for 1 digit before the decimal point (`digits = -1`)\n   - $$0.0$$ for 2 digits before the decimal point (`digits = -2`)\n   - $$0.0$$ for 3 digits before the decimal point (`digits = -3`)\n\n   The `RoundToZero` rounding mode, rounds $$12.0654$$ to:\n   - $$12.0$$ for 0 digits after the decimal point (`digits = 0`)\n   - $$12.0$$ for 1 digit after the decimal point (`digits = 1`)\n   - $$12.06$$ for 2 digits after the decimal point (`digits = 2`)\n   - $$12.065$$ for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative number refers to the digits before the decimal point.\n   - $$10.0$$ for 1 digit before the decimal point (`digits = -1`)\n   - $$0.0$$ for 2 digits before the decimal point (`digits = -2`)\n   - $$0.0$$ for 3 digits before the decimal point (`digits = -3`)\n\n   The `RoundDown` rounding mode, rounds $$12.0654$$ to:\n   - $$12.0$$ for 0 digits after the decimal point (`digits = 0`)\n   - $$12.0$$ for 1 digits after the decimal point (`digits = 1`)\n   - $$12.06$$ for 2 digits after the decimal point (`digits = 2`)\n   - $$12.065$$ for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative number refers to the digits before the decimal point.\n   - $$10.0$$ for 1 digit before the decimal point (`digits = -1`)\n   - $$0.0$$ for 2 digits before the decimal point (`digits = -2`)\n   - $$0.0$$ for 3 digits before the decimal point (`digits = -3`)\n\n   The `RoundUp` rounding mode, rounds $$12.0654$$ to:\n   - $$13.0$$ for 0 digits after the decimal point (`digits = 0`)\n   - $$12.1$$ for 1 digit after the decimal point (`digits = 1`)\n   - $$12.07$$ for 2 digits after the decimal point (`digits = 2`)\n   - $$12.066$$ for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative number refers to the digits before the decimal point.\n   - $$20.0$$ for 1 digit places before the decimal point (`digit = -1`)\n   - $$100.0$$ for 2 digits before the decimal point (`digits = -2`)\n   - $$1000.0$$ for 3 digits before the decimal point (`digits = -3`)\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/option\n     import gleam_community/maths/piecewise\n\n     pub fn example() {\n       // The default number of digits is 0 if None is provided\n       piecewise.round(12.0654, option.None, option.Some(piecewise.RoundNearest))\n       |&gt; should.equal(Ok(12.0))\n\n       // The default rounding mode is &quot;RoundNearest&quot; if None is provided \n       piecewise.round(12.0654, option.None, option.None)\n       |&gt; should.equal(Ok(12.0))\n\n       // Try different rounding modes\n       piecewise.round(12.0654, option.Some(2), option.Some(piecewise.RoundNearest))\n       |&gt; should.equal(Ok(12.07))\n\n       piecewise.round(12.0654, option.Some(2), option.Some(piecewise.RoundTiesAway))\n       |&gt; should.equal(Ok(12.07))\n\n       piecewise.round(12.0654, option.Some(2), option.Some(piecewise.RoundTiesUp))\n       |&gt; should.equal(Ok(12.07))\n\n       piecewise.round(12.0654, option.Some(2), option.Some(piecewise.RoundToZero))\n       |&gt; should.equal(Ok(12.06))\n\n       piecewise.round(12.0654, option.Some(2), option.Some(piecewise.RoundDown))\n       |&gt; should.equal(Ok(12.06))\n\n       piecewise.round(12.0654, option.Some(2), option.Some(piecewise.RoundUp))\n       |&gt; should.equal(Ok(12.07))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.round\ngleam_community/maths/piecewise round","url":"gleam_community/maths/piecewise.html#round"},{"doc":"gleam_community/maths/piecewise","title":"truncate","content":"pub fn truncate(\n  x: Float,\n  digits: Option(Int),\n) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The truncate function rounds a given input $$x \\in \\mathbb{R}$$ to the nearest integer value (at the specified digit) that is less than or equal to the absolute value of the input $$x$$.\n\n Note: The truncate function is used as an alias for the rounding function [`round`](#round) with rounding mode `RoundToZero`.\n\n &lt;details&gt;\n     &lt;summary&gt;Details&lt;/summary&gt;\n\n   For example, $$12.0654$$ is rounded to:\n   - $$12.0$$ for 0 digits after the decimal point (`digits = 0`)\n   - $$12.0$$ for 1 digits after the decimal point (`digits = 1`)\n   - $$12.06$$ for 2 digits after the decimal point (`digits = 2`)\n   - $$12.065$$ for 3 digits after the decimal point (`digits = 3`)\n\n   It is also possible to specify a negative number of digits. In that case, the negative number refers to the digits before the decimal point.\n   - $$10.0$$ for 1 digit before the decimal point (`digits = -1`)\n   - $$0.0$$ for 2 digits before the decimal point (`digits = -2`)\n   - $$0.0$$ for 3 digits before the decimal point (`digits = -3`)\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/option\n     import gleam_community/maths/piecewise\n\n     pub fn example() {\n       piecewise.truncate(12.0654, option.Some(1))\n       |&gt; should.equal(Ok(12.0))\n\n       piecewise.truncate(12.0654, option.Some(2))\n       |&gt; should.equal(Ok(12.0))\n\n       piecewise.truncate(12.0654, option.Some(3))\n       |&gt; should.equal(Ok(12.0))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/piecewise.truncate\ngleam_community/maths/piecewise truncate","url":"gleam_community/maths/piecewise.html#truncate"},{"doc":"gleam_community/maths/piecewise","title":"gleam_community/maths/piecewise","content":"&lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.css&quot; integrity=&quot;sha384-GvrOXuhMATgEsSwCs4smul74iXGOixntILdUW9XmUC6+HX0sLNAK3q71HotJqlAn&quot; crossorigin=&quot;anonymous&quot;&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.js&quot; integrity=&quot;sha384-cpW21h6RZv/phavutF+AuVYrr+dA8xD9zs6FwLpaCct6O9ctzYFfFr4dgmgccOTx&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/contrib/auto-render.min.js&quot; integrity=&quot;sha384-+VBxd3r6XgURycqtZ117nYw44OOcIax56Z4dCRWbxyPt0Koah1uHoK0o4+/RRE05&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script&gt;\n    document.addEventListener(&quot;DOMContentLoaded&quot;, function() {\n        renderMathInElement(document.body, {\n          // customised options\n          // • auto-render specific keys, e.g.:\n          delimiters: [\n              {left: &#39;$$&#39;, right: &#39;$$&#39;, display: false},\n            //   {left: &#39;$&#39;, right: &#39;$&#39;, display: false},\n            //   {left: &#39;\\\\(&#39;, right: &#39;\\\\)&#39;, display: false},\n              {left: &#39;\\\\[&#39;, right: &#39;\\\\]&#39;, display: true}\n          ],\n          // • rendering keys, e.g.:\n          throwOnError : false\n        });\n    });\n&lt;/script&gt;\n&lt;style&gt;\n    .katex { font-size: 1.1em; }\n&lt;/style&gt;\n \n ---\n \n Piecewise: A module containing functions that have different definitions depending on conditions or intervals of their domain.\n \n * **Rounding functions**\n   * [`ceiling`](#ceiling)\n   * [`floor`](#floor)\n   * [`truncate`](#truncate)\n   * [`round`](#round)\n * **Sign and absolute value functions**\n   * [`float_absolute_value`](#float_absolute_value)\n   * [`int_absolute_value`](#int_absolute_value)\n   * [`float_absolute_difference`](#float_absolute_difference)\n   * [`int_absolute_difference`](#int_absolute_difference)\n   * [`float_sign`](#float_sign)\n   * [`int_sign`](#int_sign)\n   * [`float_copy_sign`](#float_copy_sign)\n   * [`int_copy_sign`](#float_copy_sign)\n   * [`float_flip_sign`](#float_flip_sign)\n   * [`int_flip_sign`](#int_flip_sign)\n * **Misc. mathematical functions**\n   * [`minimum`](#minimum)\n   * [`maximum`](#maximum)\n   * [`minmax`](#minmax)\n   * [`list_minimum`](#list_minimum)\n   * [`list_maximum`](#list_maximum)\n   * [`extrema`](#extrema)\n   * [`arg_minimum`](#arg_minimum)\n   * [`arg_maximum`](#arg_maximum)\n","url":"gleam_community/maths/piecewise.html"},{"doc":"gleam_community/maths/arithmetics","title":"divisors","content":"pub fn divisors(n: Int) -&gt; List(Int)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function returns all the positive divisors of an integer, including the number iteself.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/arithmetics\n\n     pub fn example() {\n       arithmetics.divisors(4)\n       |&gt; should.equal([1, 2, 4])\n\n       arithmetics.divisors(6)\n       |&gt; should.equal([1, 2, 3, 6])\n\n       arithmetics.proper_divisors(13)\n       |&gt; should.equal([1, 13])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/arithmetics.divisors\ngleam_community/maths/arithmetics divisors","url":"gleam_community/maths/arithmetics.html#divisors"},{"doc":"gleam_community/maths/arithmetics","title":"float_cumulative_sum","content":"pub fn float_cumulative_sum(arr: List(Float)) -&gt; List(Float)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the cumulative sum of the elements in a list:\n\n \\\\[\n v_j = \\sum_{i=1}^j x_i \\\\;\\\\; \\forall j = 1,\\dots, n\n \\\\]\n\n In the formula, $$v_j$$ is the $$j$$&#39;th element in the cumulative sum of $$n$$ elements.\n That is, $$n$$ is the length of the list and $$x_i \\in \\mathbb{R}$$ is the value in the input list indexed by $$i$$. \n The value $$v_j$$ is thus the sum of the $$1$$ to $$j$$ first elements in the given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/arithmetics\n\n     pub fn example () {\n       []\n       |&gt; arithmetics.float_cumulative_sum()\n       |&gt; should.equal([])\n\n       // Valid input returns a result\n       [1.0, 2.0, 3.0]\n       |&gt; arithmetics.float_cumulative_sum()\n       |&gt; should.equal([1.0, 3.0, 6.0])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/arithmetics.float_cumulative_sum\ngleam_community/maths/arithmetics float_cumulative_sum","url":"gleam_community/maths/arithmetics.html#float_cumulative_sum"},{"doc":"gleam_community/maths/arithmetics","title":"float_cumumlative_product","content":"pub fn float_cumumlative_product(arr: List(Float)) -&gt; List(Float)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the cumulative product of the elements in a list:\n\n \\\\[\n v_j = \\prod_{i=1}^j x_i \\\\;\\\\; \\forall j = 1,\\dots, n\n \\\\]\n\n In the formula, $$v_j$$ is the $$j$$&#39;th element in the cumulative product of $$n$$ elements.\n That is, $$n$$ is the length of the list and $$x_i \\in \\mathbb{R}$$ is the value in the input list indexed by $$i$$. \n The value $$v_j$$ is thus the sum of the $$1$$ to $$j$$ first elements in the given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/arithmetics\n\n     pub fn example () {\n       // An empty list returns an error\n       []\n       |&gt; arithmetics.float_cumulative_product()\n       |&gt; should.equal([])\n\n       // Valid input returns a result\n       [1.0, 2.0, 3.0]\n       |&gt; arithmetics.float_cumulative_product()\n       |&gt; should.equal([1.0, 2.0, 6.0])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/arithmetics.float_cumumlative_product\ngleam_community/maths/arithmetics float_cumumlative_product","url":"gleam_community/maths/arithmetics.html#float_cumumlative_product"},{"doc":"gleam_community/maths/arithmetics","title":"float_product","content":"pub fn float_product(arr: List(Float)) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the product of the elements in a list:\n\n \\\\[\n \\prod_{i=1}^n x_i\n \\\\]\n\n In the formula, $$n$$ is the length of the list and $$x_i \\in \\mathbb{R}$$ is the value in the input list indexed by $$i$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/arithmetics\n\n     pub fn example () {\n       // An empty list returns 0.0\n       []\n       |&gt; arithmetics.float_product()\n       |&gt; should.equal(0.0)\n\n       // Valid input returns a result\n       [1.0, 2.0, 3.0]\n       |&gt; arithmetics.float_product()\n       |&gt; should.equal(6.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/arithmetics.float_product\ngleam_community/maths/arithmetics float_product","url":"gleam_community/maths/arithmetics.html#float_product"},{"doc":"gleam_community/maths/arithmetics","title":"float_sum","content":"pub fn float_sum(arr: List(Float)) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the sum of the elements in a list:\n\n \\\\[\n \\sum_{i=1}^n x_i\n \\\\]\n\n In the formula, $$n$$ is the length of the list and $$x_i \\in \\mathbb{R}$$ is the value in the input list indexed by $$i$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/arithmetics\n\n     pub fn example () {\n       // An empty list returns an error\n       []\n       |&gt; arithmetics.float_sum()\n       |&gt; should.equal(0.0)\n\n       // Valid input returns a result\n       [1.0, 2.0, 3.0]\n       |&gt; arithmetics.float_sum()\n       |&gt; should.equal(6.0)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/arithmetics.float_sum\ngleam_community/maths/arithmetics float_sum","url":"gleam_community/maths/arithmetics.html#float_sum"},{"doc":"gleam_community/maths/arithmetics","title":"gcd","content":"pub fn gcd(x: Int, y: Int) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function calculates the greatest common multiple of two integers $$x, y \\in \\mathbb{Z}$$.\n The greatest common multiple is the largest positive integer that is divisible by both $$x$$ and $$y$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/arithmetics\n\n     pub fn example() {\n       arithmetics.lcm(1, 1)\n       |&gt; should.equal(1)\n   \n       arithmetics.lcm(100, 10)\n       |&gt; should.equal(10)\n\n       arithmetics.gcd(-36, -17)\n       |&gt; should.equal(1)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/arithmetics.gcd\ngleam_community/maths/arithmetics gcd","url":"gleam_community/maths/arithmetics.html#gcd"},{"doc":"gleam_community/maths/arithmetics","title":"int_cumulative_product","content":"pub fn int_cumulative_product(arr: List(Int)) -&gt; List(Int)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the cumulative product of the elements in a list:\n\n \\\\[\n v_j = \\prod_{i=1}^j x_i \\\\;\\\\; \\forall j = 1,\\dots, n\n \\\\]\n\n In the formula, $$v_j$$ is the $$j$$&#39;th element in the cumulative product of $$n$$ elements.\n That is, $$n$$ is the length of the list and $$x_i \\in \\mathbb{Z}$$ is the value in the input list indexed by $$i$$. \n The value $$v_j$$ is thus the product of the $$1$$ to $$j$$ first elements in the given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/arithmetics\n\n     pub fn example () {\n       // An empty list returns an error\n       []\n       |&gt; arithmetics.int_cumulative_product()\n       |&gt; should.equal([])\n\n       // Valid input returns a result\n       [1, 2, 3]\n       |&gt; arithmetics.int_cumulative_product()\n       |&gt; should.equal([1, 2, 6])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/arithmetics.int_cumulative_product\ngleam_community/maths/arithmetics int_cumulative_product","url":"gleam_community/maths/arithmetics.html#int_cumulative_product"},{"doc":"gleam_community/maths/arithmetics","title":"int_cumulative_sum","content":"pub fn int_cumulative_sum(arr: List(Int)) -&gt; List(Int)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the cumulative sum of the elements in a list:\n\n \\\\[\n v_j = \\sum_{i=1}^j x_i \\\\;\\\\; \\forall j = 1,\\dots, n\n \\\\]\n\n In the formula, $$v_j$$ is the $$j$$&#39;th element in the cumulative sum of $$n$$ elements.\n That is, $$n$$ is the length of the list and $$x_i \\in \\mathbb{Z}$$ is the value in the input list indexed by $$i$$. \n The value $$v_j$$ is thus the sum of the $$1$$ to $$j$$ first elements in the given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/arithmetics\n\n     pub fn example () {\n       []\n       |&gt; arithmetics.int_cumulative_sum()\n       |&gt; should.equal([])\n\n       // Valid input returns a result\n       [1, 2, 3]\n       |&gt; arithmetics.int_cumulative_sum()\n       |&gt; should.equal([1, 3, 6])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/arithmetics.int_cumulative_sum\ngleam_community/maths/arithmetics int_cumulative_sum","url":"gleam_community/maths/arithmetics.html#int_cumulative_sum"},{"doc":"gleam_community/maths/arithmetics","title":"int_product","content":"pub fn int_product(arr: List(Int)) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the product of the elements in a list:\n\n \\\\[\n \\prod_{i=1}^n x_i\n \\\\]\n\n In the formula, $$n$$ is the length of the list and $$x_i \\in \\mathbb{Z}$$ is the value in the input list indexed by $$i$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/arithmetics\n\n     pub fn example () {\n       // An empty list returns 0\n       []\n       |&gt; arithmetics.int_product()\n       |&gt; should.equal(0)\n\n       // Valid input returns a result\n       [1, 2, 3]\n       |&gt; arithmetics.int_product()\n       |&gt; should.equal(6)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/arithmetics.int_product\ngleam_community/maths/arithmetics int_product","url":"gleam_community/maths/arithmetics.html#int_product"},{"doc":"gleam_community/maths/arithmetics","title":"int_sum","content":"pub fn int_sum(arr: List(Int)) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the sum of the elements in a list:\n\n \\\\[\n \\sum_{i=1}^n x_i\n \\\\]\n\n In the formula, $$n$$ is the length of the list and $$x_i \\in \\mathbb{Z}$$ is the value in the input list indexed by $$i$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/arithmetics\n\n     pub fn example () {\n       // An empty list returns 0\n       []\n       |&gt; arithmetics.int_sum()\n       |&gt; should.equal(0)\n\n       // Valid input returns a result\n       [1, 2, 3]\n       |&gt; arithmetics.int_sum()\n       |&gt; should.equal(6)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/arithmetics.int_sum\ngleam_community/maths/arithmetics int_sum","url":"gleam_community/maths/arithmetics.html#int_sum"},{"doc":"gleam_community/maths/arithmetics","title":"lcm","content":"pub fn lcm(x: Int, y: Int) -&gt; Int\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function calculates the least common multiple of two integers $$x, y \\in \\mathbb{Z}$$.\n The least common multiple is the smallest positive integer that has both $$x$$ and $$y$$ as factors.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/arithmetics\n\n     pub fn example() {\n       arithmetics.lcm(1, 1)\n       |&gt; should.equal(1)\n   \n       arithmetics.lcm(100, 10)\n       |&gt; should.equal(100)\n\n       arithmetics.lcm(-36, -17)\n       |&gt; should.equal(612)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/arithmetics.lcm\ngleam_community/maths/arithmetics lcm","url":"gleam_community/maths/arithmetics.html#lcm"},{"doc":"gleam_community/maths/arithmetics","title":"proper_divisors","content":"pub fn proper_divisors(n: Int) -&gt; List(Int)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function returns all the positive divisors of an integer, excluding the number iteself.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/arithmetics\n\n     pub fn example() {\n       arithmetics.proper_divisors(4)\n       |&gt; should.equal([1, 2])\n\n       arithmetics.proper_divisors(6)\n       |&gt; should.equal([1, 2, 3])\n\n       arithmetics.proper_divisors(13)\n       |&gt; should.equal([1])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/arithmetics.proper_divisors\ngleam_community/maths/arithmetics proper_divisors","url":"gleam_community/maths/arithmetics.html#proper_divisors"},{"doc":"gleam_community/maths/arithmetics","title":"gleam_community/maths/arithmetics","content":"&lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.css&quot; integrity=&quot;sha384-GvrOXuhMATgEsSwCs4smul74iXGOixntILdUW9XmUC6+HX0sLNAK3q71HotJqlAn&quot; crossorigin=&quot;anonymous&quot;&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.js&quot; integrity=&quot;sha384-cpW21h6RZv/phavutF+AuVYrr+dA8xD9zs6FwLpaCct6O9ctzYFfFr4dgmgccOTx&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/contrib/auto-render.min.js&quot; integrity=&quot;sha384-+VBxd3r6XgURycqtZ117nYw44OOcIax56Z4dCRWbxyPt0Koah1uHoK0o4+/RRE05&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script&gt;\n    document.addEventListener(&quot;DOMContentLoaded&quot;, function() {\n        renderMathInElement(document.body, {\n          // customised options\n          // • auto-render specific keys, e.g.:\n          delimiters: [\n              {left: &#39;$$&#39;, right: &#39;$$&#39;, display: false},\n            //   {left: &#39;$&#39;, right: &#39;$&#39;, display: false},\n            //   {left: &#39;\\\\(&#39;, right: &#39;\\\\)&#39;, display: false},\n              {left: &#39;\\\\[&#39;, right: &#39;\\\\]&#39;, display: true}\n          ],\n          // • rendering keys, e.g.:\n          throwOnError : false\n        });\n    });\n&lt;/script&gt;\n&lt;style&gt;\n    .katex { font-size: 1.1em; }\n&lt;/style&gt;\n \n ---\n \n Arithmetics: A module containing a collection of fundamental mathematical functions relating to simple arithmetics (addition, subtraction, multiplication, etc.), but also number theory.\n \n * **Division functions**\n   * [`gcd`](#gcd)\n   * [`lcm`](#lcm)\n   * [`divisors`](#divisors)\n   * [`proper_divisors`](#proper_divisors)\n * **Sums and products**\n   * [`float_sum`](#float_sum)\n   * [`int_sum`](#int_sum)\n   * [`float_product`](#float_product)\n   * [`int_product`](#int_product)\n   * [`float_cumulative_sum`](#float_cumulative_sum)\n   * [`int_cumulative_sum`](#int_cumulative_sum)\n   * [`float_cumulative_product`](#float_cumulative_product)\n   * [`int_cumulative_product`](#int_cumulative_product)\n ","url":"gleam_community/maths/arithmetics.html"},{"doc":"gleam_community/maths/predicates","title":"all_close","content":"pub fn all_close(\n  xarr: List(Float),\n  yarr: List(Float),\n  rtol: Float,\n  atol: Float,\n) -&gt; Result(List(Bool), String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Determine if a list of values are close to or equivalent to a another list of reference values.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/list\n     import gleam_community/maths/tests\n\n     pub fn example () {\n       let val: Float = 99.\n       let ref_val: Float = 100.\n       let xarr: List(Float) = list.repeat(val, 42)\n       let yarr: List(Float) = list.repeat(ref_val, 42)\n       // We set &#39;atol&#39; and &#39;rtol&#39; such that the values are equivalent\n       // if &#39;val&#39; is within 1 percent of &#39;ref_val&#39; +/- 0.1\n       let rtol: Float = 0.01\n       let atol: Float = 0.10\n       tests.all_close(xarr, yarr, rtol, atol)\n       |&gt; fn(zarr: Result(List(Bool), String)) -&gt; Result(Bool, Nil) {\n         case zarr {\n           Ok(arr) -&gt;\n             arr\n             |&gt; list.all(fn(a: Bool) -&gt; Bool { a })\n             |&gt; Ok\n           _ -&gt; Nil |&gt; Error\n         }\n       }\n       |&gt; should.equal(Ok(True))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/predicates.all_close\ngleam_community/maths/predicates all_close","url":"gleam_community/maths/predicates.html#all_close"},{"doc":"gleam_community/maths/predicates","title":"is_close","content":"pub fn is_close(\n  a: Float,\n  b: Float,\n  rtol: Float,\n  atol: Float,\n) -&gt; Bool\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Determine if a given value $$a$$ is close to or equivalent to a reference value \n $$b$$ based on supplied relative $$r_{tol}$$ and absolute $$a_{tol}$$ tolerance values.\n The equivalance of the two given values are then determined based on the equation:\n\n \\\\[\n     \\|a - b\\| \\leq (a_{tol} + r_{tol} \\cdot \\|b\\|)\n \\\\]\n\n `True` is returned if statement holds, otherwise `False` is returned. \n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/tests\n\n     pub fn example () {\n       let val: Float = 99.\n       let ref_val: Float = 100.\n       // We set &#39;atol&#39; and &#39;rtol&#39; such that the values are equivalent\n       // if &#39;val&#39; is within 1 percent of &#39;ref_val&#39; +/- 0.1\n       let rtol: Float = 0.01\n       let atol: Float = 0.10\n       floatx.is_close(val, ref_val, rtol, atol)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/predicates.is_close\ngleam_community/maths/predicates is_close","url":"gleam_community/maths/predicates.html#is_close"},{"doc":"gleam_community/maths/predicates","title":"is_even","content":"pub fn is_even(x: Int) -&gt; Bool\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A function that tests whether a given integer value $$x \\in \\mathbb{Z}$$ is even.  \n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/tests\n\n     pub fn example() {\n       tests.is_even(-3)\n       |&gt; should.equal(False)\n     \n       tests.is_even(-4)\n       |&gt; should.equal(True)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/predicates.is_even\ngleam_community/maths/predicates is_even","url":"gleam_community/maths/predicates.html#is_even"},{"doc":"gleam_community/maths/predicates","title":"is_fractional","content":"pub fn is_fractional(x: Float) -&gt; Bool\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Determine if a given value is fractional.\n \n `True` is returned if the given value is fractional, otherwise `False` is returned. \n \n &lt;details&gt;\n     &lt;summary&gt;Example&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/tests\n\n     pub fn example () {\n       tests.is_fractional(0.3333)\n       |&gt; should.equal(True)\n       \n       tests.is_fractional(1.0)\n       |&gt; should.equal(False)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/predicates.is_fractional\ngleam_community/maths/predicates is_fractional","url":"gleam_community/maths/predicates.html#is_fractional"},{"doc":"gleam_community/maths/predicates","title":"is_odd","content":"pub fn is_odd(x: Int) -&gt; Bool\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A function that tests whether a given integer value $$x \\in \\mathbb{Z}$$ is odd.  \n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/tests\n\n     pub fn example() {\n       tests.is_odd(-3)\n       |&gt; should.equal(True)\n     \n       tests.is_odd(-4)\n       |&gt; should.equal(False)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/predicates.is_odd\ngleam_community/maths/predicates is_odd","url":"gleam_community/maths/predicates.html#is_odd"},{"doc":"gleam_community/maths/predicates","title":"is_perfect","content":"pub fn is_perfect(n: Int) -&gt; Bool\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A function that tests whether a given integer value $$n \\in \\mathbb{Z}$$ is a perfect number. A number is perfect if it is equal to the sum of its proper positive divisors.\n \n &lt;details&gt;\n     &lt;summary&gt;Details&lt;/summary&gt;\n\n   For example:\n   - $$6$$ is a perfect number since the divisors of 6 are $$1 + 2 + 3 = 6$$.\n   - $$28$$ is a perfect number since the divisors of 28 are $$1 + 2 + 4 + 7 + 14 = 28$$\n\n &lt;/details&gt;\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/tests\n\n     pub fn example() {\n       tests.is_perfect(6)\n       |&gt; should.equal(True)\n\n       tests.is_perfect(28)\n       |&gt; should.equal(True)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/predicates.is_perfect\ngleam_community/maths/predicates is_perfect","url":"gleam_community/maths/predicates.html#is_perfect"},{"doc":"gleam_community/maths/predicates","title":"is_power","content":"pub fn is_power(x: Int, y: Int) -&gt; Bool\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A function that tests whether a given integer value $$x \\in \\mathbb{Z}$$ is a power of another integer value $$y \\in \\mathbb{Z}$$.  \n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/tests\n\n     pub fn example() {\n       // Check if 4 is a power of 2 (it is)\n       tests.is_power(4, 2)\n       |&gt; should.equal(True)\n\n       // Check if 5 is a power of 2 (it is not)\n       tests.is_power(5, 2)\n       |&gt; should.equal(False)\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/predicates.is_power\ngleam_community/maths/predicates is_power","url":"gleam_community/maths/predicates.html#is_power"},{"doc":"gleam_community/maths/predicates","title":"gleam_community/maths/predicates","content":"&lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.css&quot; integrity=&quot;sha384-GvrOXuhMATgEsSwCs4smul74iXGOixntILdUW9XmUC6+HX0sLNAK3q71HotJqlAn&quot; crossorigin=&quot;anonymous&quot;&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.js&quot; integrity=&quot;sha384-cpW21h6RZv/phavutF+AuVYrr+dA8xD9zs6FwLpaCct6O9ctzYFfFr4dgmgccOTx&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/contrib/auto-render.min.js&quot; integrity=&quot;sha384-+VBxd3r6XgURycqtZ117nYw44OOcIax56Z4dCRWbxyPt0Koah1uHoK0o4+/RRE05&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script&gt;\n    document.addEventListener(&quot;DOMContentLoaded&quot;, function() {\n        renderMathInElement(document.body, {\n          // customised options\n          // • auto-render specific keys, e.g.:\n          delimiters: [\n              {left: &#39;$$&#39;, right: &#39;$$&#39;, display: false},\n            //   {left: &#39;$&#39;, right: &#39;$&#39;, display: false},\n            //   {left: &#39;\\\\(&#39;, right: &#39;\\\\)&#39;, display: false},\n              {left: &#39;\\\\[&#39;, right: &#39;\\\\]&#39;, display: true}\n          ],\n          // • rendering keys, e.g.:\n          throwOnError : false\n        });\n    });\n&lt;/script&gt;\n&lt;style&gt;\n    .katex { font-size: 1.1em; }\n&lt;/style&gt;\n \n ---\n \n Predicates: A module containing functions for testing various mathematical properties of numbers.\n \n * **Tests**\n   * [`is_close`](#is_close)\n   * [`list_all_close`](#all_close)\n   * [`is_fractional`](#is_fractional)\n   * [`is_power`](#is_power)\n   * [`is_perfect`](#is_perfect)\n   * [`is_even`](#is_even)\n   * [`is_odd`](#is_odd)","url":"gleam_community/maths/predicates.html"},{"doc":"gleam_community/maths/special","title":"beta","content":"pub fn beta(x: Float, y: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The beta function over the real numbers:\n\n \\\\[\n \\text{B}(x, y) = \\frac{\\Gamma(x) \\cdot \\Gamma(y)}{\\Gamma(x + y)}\n \\\\]\n\n The beta function is evaluated through the use of the gamma function.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/special.beta\ngleam_community/maths/special beta","url":"gleam_community/maths/special.html#beta"},{"doc":"gleam_community/maths/special","title":"erf","content":"pub fn erf(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The error function.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/special.erf\ngleam_community/maths/special erf","url":"gleam_community/maths/special.html#erf"},{"doc":"gleam_community/maths/special","title":"gamma","content":"pub fn gamma(x: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The gamma function over the real numbers. The function is essentially equal to the\n factorial for any positive integer argument: $$\\Gamma(n) = (n - 1)!$$\n\n The implemented gamma function is approximated through Lanczos approximation\n using the same coefficients used by the GNU Scientific Library.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/special.gamma\ngleam_community/maths/special gamma","url":"gleam_community/maths/special.html#gamma"},{"doc":"gleam_community/maths/special","title":"incomplete_gamma","content":"pub fn incomplete_gamma(\n  a: Float,\n  x: Float,\n) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The lower incomplete gamma function over the real numbers.\n\n The implemented incomplete gamma function is evaluated through a power series\n expansion.\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/special.incomplete_gamma\ngleam_community/maths/special incomplete_gamma","url":"gleam_community/maths/special.html#incomplete_gamma"},{"doc":"gleam_community/maths/special","title":"gleam_community/maths/special","content":"&lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.css&quot; integrity=&quot;sha384-GvrOXuhMATgEsSwCs4smul74iXGOixntILdUW9XmUC6+HX0sLNAK3q71HotJqlAn&quot; crossorigin=&quot;anonymous&quot;&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.js&quot; integrity=&quot;sha384-cpW21h6RZv/phavutF+AuVYrr+dA8xD9zs6FwLpaCct6O9ctzYFfFr4dgmgccOTx&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/contrib/auto-render.min.js&quot; integrity=&quot;sha384-+VBxd3r6XgURycqtZ117nYw44OOcIax56Z4dCRWbxyPt0Koah1uHoK0o4+/RRE05&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script&gt;\n    document.addEventListener(&quot;DOMContentLoaded&quot;, function() {\n        renderMathInElement(document.body, {\n          // customised options\n          // • auto-render specific keys, e.g.:\n          delimiters: [\n              {left: &#39;$$&#39;, right: &#39;$$&#39;, display: false},\n            //   {left: &#39;$&#39;, right: &#39;$&#39;, display: false},\n            //   {left: &#39;\\\\(&#39;, right: &#39;\\\\)&#39;, display: false},\n              {left: &#39;\\\\[&#39;, right: &#39;\\\\]&#39;, display: true}\n          ],\n          // • rendering keys, e.g.:\n          throwOnError : false\n        });\n    });\n&lt;/script&gt;\n&lt;style&gt;\n    .katex { font-size: 1.1em; }\n&lt;/style&gt;\n \n ---\n \n Special: A module containing special mathematical functions.\n \n * **Special mathematical functions**\n   * [`beta`](#beta)\n   * [`erf`](#erf)\n   * [`gamma`](#gamma)\n   * [`incomplete_gamma`](#incomplete_gamma)\n ","url":"gleam_community/maths/special.html"},{"doc":"gleam_community/maths/sequences","title":"arange","content":"pub fn arange(\n  start: Float,\n  stop: Float,\n  step: Float,\n) -&gt; List(Float)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function returns a list with evenly spaced values within a given interval based on a start, stop value and a given increment (step-length) between consecutive values. \n The list returned includes the given start value but excludes the stop value.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/sequences\n\n     pub fn example () {\n       sequences.arange(1.0, 5.0, 1.0)\n       |&gt; should.equal([1.0, 2.0, 3.0, 4.0])\n       \n       // No points returned since\n       // start smaller than stop and positive step\n       sequences.arange(5.0, 1.0, 1.0)\n       |&gt; should.equal([])\n       \n       // Points returned since\n       // start smaller than stop but negative step\n       sequences.arange(5.0, 1.0, -1.0)\n       |&gt; should.equal([5.0, 4.0, 3.0, 2.0])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/sequences.arange\ngleam_community/maths/sequences arange","url":"gleam_community/maths/sequences.html#arange"},{"doc":"gleam_community/maths/sequences","title":"geometric_space","content":"pub fn geometric_space(\n  start: Float,\n  stop: Float,\n  num: Int,\n  endpoint: Bool,\n) -&gt; Result(List(Float), String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n The function returns a list of numbers spaced evenly on a log scale (a geometric progression). Each point in the list is a constant multiple of the previous.\n The function is similar to the [`logarithmic_space`](#logarithmic_space) function, but with endpoints specified directly.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n     import gleam_community/maths/sequences\n     import gleam_community/maths/predicates\n\n     pub fn example () {\n       let assert Ok(tol) = elementary.power(-10.0, -6.0)\n       let assert Ok(logspace) = sequences.geometric_space(10.0, 1000.0, 3, True)\n       let assert Ok(result) =\n         predicates.all_close(logspace, [10.0, 100.0, 1000.0], 0.0, tol)\n       result\n       |&gt; list.all(fn(x) { x == True })\n       |&gt; should.be_true()\n\n       // Input (start and stop can&#39;t be equal to 0.0)\n       sequences.geometric_space(0.0, 1000.0, 3, False)\n       |&gt; should.be_error()\n     \n       sequences.geometric_space(-1000.0, 0.0, 3, False)\n       |&gt; should.be_error()\n\n       // A negative number of points (-3) does not work\n       sequences.geometric_space(10.0, 1000.0, -3, False)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/sequences.geometric_space\ngleam_community/maths/sequences geometric_space","url":"gleam_community/maths/sequences.html#geometric_space"},{"doc":"gleam_community/maths/sequences","title":"linear_space","content":"pub fn linear_space(\n  start: Float,\n  stop: Float,\n  num: Int,\n  endpoint: Bool,\n) -&gt; Result(List(Float), String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Generate a linearly spaced list of points over a specified interval. The endpoint of the interval can optionally be included/excluded.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n     import gleam_community/maths/sequences\n     import gleam_community/maths/predicates\n\n     pub fn example () {\n       let assert Ok(tol) = elementary.power(-10.0, -6.0)\n       let assert Ok(linspace) = sequences.linear_space(10.0, 50.0, 5, True)\n       let assert Ok(result) =\n         predicates.all_close(linspace, [10.0, 20.0, 30.0, 40.0, 50.0], 0.0, tol)\n       result\n       |&gt; list.all(fn(x) { x == True })\n       |&gt; should.be_true()\n\n       // A negative number of points (-5) does not work\n       sequences.linear_space(10.0, 50.0, -5, True)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/sequences.linear_space\ngleam_community/maths/sequences linear_space","url":"gleam_community/maths/sequences.html#linear_space"},{"doc":"gleam_community/maths/sequences","title":"logarithmic_space","content":"pub fn logarithmic_space(\n  start: Float,\n  stop: Float,\n  num: Int,\n  endpoint: Bool,\n  base: Float,\n) -&gt; Result(List(Float), String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Generate a logarithmically spaced list of points over a specified interval. The endpoint of the interval can optionally be included/excluded.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n     import gleam_community/maths/sequences\n     import gleam_community/maths/predicates\n\n     pub fn example () {\n       let assert Ok(tol) = elementary.power(-10.0, -6.0)\n       let assert Ok(logspace) = sequences.logarithmic_space(1.0, 3.0, 3, True, 10.0)\n       let assert Ok(result) =\n         predicates.all_close(logspace, [10.0, 100.0, 1000.0], 0.0, tol)\n       result\n       |&gt; list.all(fn(x) { x == True })\n       |&gt; should.be_true()\n\n       // A negative number of points (-3) does not work\n       sequences.logarithmic_space(1.0, 3.0, -3, False, 10.0)\n       |&gt; should.be_error()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/sequences.logarithmic_space\ngleam_community/maths/sequences logarithmic_space","url":"gleam_community/maths/sequences.html#logarithmic_space"},{"doc":"gleam_community/maths/sequences","title":"gleam_community/maths/sequences","content":"&lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.css&quot; integrity=&quot;sha384-GvrOXuhMATgEsSwCs4smul74iXGOixntILdUW9XmUC6+HX0sLNAK3q71HotJqlAn&quot; crossorigin=&quot;anonymous&quot;&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.js&quot; integrity=&quot;sha384-cpW21h6RZv/phavutF+AuVYrr+dA8xD9zs6FwLpaCct6O9ctzYFfFr4dgmgccOTx&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/contrib/auto-render.min.js&quot; integrity=&quot;sha384-+VBxd3r6XgURycqtZ117nYw44OOcIax56Z4dCRWbxyPt0Koah1uHoK0o4+/RRE05&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script&gt;\n    document.addEventListener(&quot;DOMContentLoaded&quot;, function() {\n        renderMathInElement(document.body, {\n          // customised options\n          // • auto-render specific keys, e.g.:\n          delimiters: [\n              {left: &#39;$$&#39;, right: &#39;$$&#39;, display: false},\n            //   {left: &#39;$&#39;, right: &#39;$&#39;, display: false},\n            //   {left: &#39;\\\\(&#39;, right: &#39;\\\\)&#39;, display: false},\n              {left: &#39;\\\\[&#39;, right: &#39;\\\\]&#39;, display: true}\n          ],\n          // • rendering keys, e.g.:\n          throwOnError : false\n        });\n    });\n&lt;/script&gt;\n&lt;style&gt;\n    .katex { font-size: 1.1em; }\n&lt;/style&gt;\n \n ---\n \n Sequences: A module containing functions for generating various types of sequences, ranges and intervals.\n \n * **Ranges and intervals**\n   * [`arange`](#arange)\n   * [`linear_space`](#linear_space)\n   * [`logarithmic_space`](#logarithmic_space)\n   * [`geometric_space`](#geometric_space)","url":"gleam_community/maths/sequences.html"},{"doc":"gleam_community/maths/metrics","title":"euclidean_distance","content":"pub fn euclidean_distance(\n  xarr: List(Float),\n  yarr: List(Float),\n) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the Euclidean distance between two lists (representing vectors):\n\n \\\\[\n \\left( \\sum_{i=1}^n \\left|x_i - y_i \\right|^{2} \\right)^{\\frac{1}{2}}\n \\\\]\n\n In the formula, $$n$$ is the length of the two lists and $$x_i, y_i$$ are the values in the respective input lists indexed by $$i, j$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n     import gleam_community/maths/metrics\n     import gleam_community/maths/predicates\n\n     pub fn example () {\n       let assert Ok(tol) = elementary.power(-10.0, -6.0)\n     \n       // Empty lists returns 0.0\n       metrics.euclidean_distance([], [])\n       |&gt; should.equal(Ok(0.0))\n     \n       // Differing lengths returns error\n       metrics.euclidean_distance([], [1.0])\n       |&gt; should.be_error()\n     \n       let assert Ok(result) = metrics.euclidean_distance([0.0, 0.0], [1.0, 2.0])\n       result\n       |&gt; predicates.is_close(2.23606797749979, 0.0, tol)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/metrics.euclidean_distance\ngleam_community/maths/metrics euclidean_distance","url":"gleam_community/maths/metrics.html#euclidean_distance"},{"doc":"gleam_community/maths/metrics","title":"manhatten_distance","content":"pub fn manhatten_distance(\n  xarr: List(Float),\n  yarr: List(Float),\n) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the Manhatten distance between two lists (representing vectors):\n\n \\\\[\n \\sum_{i=1}^n \\left|x_i - y_i \\right|\n \\\\]\n\n In the formula, $$n$$ is the length of the two lists and $$x_i, y_i$$ are the values in the respective input lists indexed by $$i, j$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n     import gleam_community/maths/metrics\n     import gleam_community/maths/predicates\n\n     pub fn example () {\n       let assert Ok(tol) = elementary.power(-10.0, -6.0)\n     \n       // Empty lists returns 0.0\n       metrics.float_manhatten_distance([], [])\n       |&gt; should.equal(Ok(0.0))\n     \n       // Differing lengths returns error\n       metrics.manhatten_distance([], [1.0])\n       |&gt; should.be_error()\n     \n       let assert Ok(result) = metrics.manhatten_distance([0.0, 0.0], [1.0, 2.0])\n       result\n       |&gt; predicates.is_close(3.0, 0.0, tol)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/metrics.manhatten_distance\ngleam_community/maths/metrics manhatten_distance","url":"gleam_community/maths/metrics.html#manhatten_distance"},{"doc":"gleam_community/maths/metrics","title":"mean","content":"pub fn mean(arr: List(Float)) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/nicklasxyz/gleam_stats/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the arithmetic mean of the elements in a list:\n\n \\\\[\n \\bar{x} = \\frac{1}{n}\\sum_{i=1}^n x_i\n \\\\]\n\n In the formula, $$n$$ is the sample size (the length of the list) and \n $$x_i$$ is the sample point in the input list indexed by $$i$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/metrics\n\n     pub fn example () {\n       // An empty list returns an error\n       []\n       |&gt; metrics.mean()\n       |&gt; should.be_error()\n\n       // Valid input returns a result\n       [1., 2., 3.]\n       |&gt; metrics.mean()\n       |&gt; should.equal(Ok(2.))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/metrics.mean\ngleam_community/maths/metrics mean","url":"gleam_community/maths/metrics.html#mean"},{"doc":"gleam_community/maths/metrics","title":"median","content":"pub fn median(arr: List(Float)) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/nicklasxyz/gleam_stats/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the median of the elements in a list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/metrics\n\n     pub fn example () {\n       // An empty list returns an error\n       []\n       |&gt; metrics.median()\n       |&gt; should.be_error()\n\n       // Valid input returns a result\n       [1., 2., 3.]\n       |&gt; metrics.median()\n       |&gt; should.equal(Ok(2.))\n     \n       [1., 2., 3., 4.]\n       |&gt; metrics.median()\n       |&gt; should.equal(Ok(2.5))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/metrics.median\ngleam_community/maths/metrics median","url":"gleam_community/maths/metrics.html#median"},{"doc":"gleam_community/maths/metrics","title":"minkowski_distance","content":"pub fn minkowski_distance(\n  xarr: List(Float),\n  yarr: List(Float),\n  p: Float,\n) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the Minkowski distance between two lists (representing vectors):\n\n \\\\[\n \\left( \\sum_{i=1}^n \\left|x_i - y_i \\right|^{p} \\right)^{\\frac{1}{p}}\n \\\\]\n\n In the formula, $$p &gt;= 1$$ is the order, $$n$$ is the length of the two lists and $$x_i, y_i$$ are the values in the respective input lists indexed by $$i, j$$.\n\n The Minkowski distance is a generalization of both the Euclidean distance ($$p=2$$) and the Manhattan distance ($$p = 1$$).\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n     import gleam_community/maths/metrics\n     import gleam_community/maths/predicates\n\n     pub fn example () {\n       let assert Ok(tol) = elementary.power(-10.0, -6.0)\n     \n       // Empty lists returns 0.0\n       metrics.minkowski_distance([], [], 1.0)\n       |&gt; should.equal(Ok(0.0))\n     \n       // Differing lengths returns error\n       metrics.minkowski_distance([], [1.0], 1.0)\n       |&gt; should.be_error()\n     \n       // Test order &lt; 1\n       metrics.minkowski_distance([0.0, 0.0], [0.0, 0.0], -1.0)\n       |&gt; should.be_error()\n     \n       let assert Ok(result) = metrics.minkowski_distance([0.0, 0.0], [1.0, 2.0], 1.0)\n       result\n       |&gt; predicates.is_close(3.0, 0.0, tol)\n       |&gt; should.be_true()  \n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/metrics.minkowski_distance\ngleam_community/maths/metrics minkowski_distance","url":"gleam_community/maths/metrics.html#minkowski_distance"},{"doc":"gleam_community/maths/metrics","title":"norm","content":"pub fn norm(arr: List(Float), p: Float) -&gt; Float\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the $$p$$-norm of a list (representing a vector):\n\n \\\\[\n \\left( \\sum_{i=1}^n \\left|x_i\\right|^{p} \\right)^{\\frac{1}{p}}\n \\\\]\n\n In the formula, $$n$$ is the length of the list and $$x_i$$ is the value in the input list indexed by $$i$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/elementary\n     import gleam_community/maths/metrics\n     import gleam_community/maths/predicates\n\n     pub fn example () {\n       let assert Ok(tol) = elementary.power(-10.0, -6.0)\n\n       [1.0, 1.0, 1.0]\n       |&gt; metrics.norm(1.0)\n       |&gt; predicates.is_close(3.0, 0.0, tol)\n       |&gt; should.be_true()\n\n       [1.0, 1.0, 1.0]\n       |&gt; metrics.norm(-1.0)\n       |&gt; predicates.is_close(0.3333333333333333, 0.0, tol)\n       |&gt; should.be_true()\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/metrics.norm\ngleam_community/maths/metrics norm","url":"gleam_community/maths/metrics.html#norm"},{"doc":"gleam_community/maths/metrics","title":"standard_deviation","content":"pub fn standard_deviation(\n  arr: List(Float),\n  ddof: Int,\n) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/nicklasxyz/gleam_stats/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the sample standard deviation of the elements in a list:\n \\\\[\n s = \\left(\\frac{1}{n - d} \\sum_{i=1}^{n}(x_i - \\bar{x})\\right)^{\\frac{1}{2}}\n \\\\]\n\n In the formula, $$n$$ is the sample size (the length of the list) and \n $$x_i$$ is the sample point in the input list indexed by $$i$$. \n Furthermore, $$\\bar{x}$$ is the sample mean and $$d$$ is the &quot;Delta \n Degrees of Freedom&quot;, and is by default set to $$d = 0$$, which gives a biased\n estimate of the sample standard deviation. Setting $$d = 1$$ gives an unbiased estimate.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/metrics\n\n     pub fn example () {\n       // Degrees of freedom\n       let ddof: Int = 1\n     \n       // An empty list returns an error\n       []\n       |&gt; metrics.standard_deviationddof)\n       |&gt; should.be_error()\n     \n       // Valid input returns a result\n       [1., 2., 3.]\n       |&gt; metrics.standard_deviation(ddof)\n       |&gt; should.equal(Ok(1.))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/metrics.standard_deviation\ngleam_community/maths/metrics standard_deviation","url":"gleam_community/maths/metrics.html#standard_deviation"},{"doc":"gleam_community/maths/metrics","title":"variance","content":"pub fn variance(\n  arr: List(Float),\n  ddof: Int,\n) -&gt; Result(Float, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/nicklasxyz/gleam_stats/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Calculcate the sample variance of the elements in a list:\n \\\\[\n s^{2} = \\frac{1}{n - d} \\sum_{i=1}^{n}(x_i - \\bar{x})\n \\\\]\n\n In the formula, $$n$$ is the sample size (the length of the list) and \n $$x_i$$ is the sample point in the input list indexed by $$i$$. \n Furthermore, $$\\bar{x}$$ is the sample mean and $$d$$ is the &quot;Delta \n Degrees of Freedom&quot;, and is by default set to $$d = 0$$, which gives a biased\n estimate of the sample variance. Setting $$d = 1$$ gives an unbiased estimate.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/metrics\n\n     pub fn example () {\n       // Degrees of freedom\n       let ddof: Int = 1\n     \n       // An empty list returns an error\n       []\n       |&gt; metrics.variance(ddof)\n       |&gt; should.be_error()\n     \n       // Valid input returns a result\n       [1., 2., 3.]\n       |&gt; metrics.variance(ddof)\n       |&gt; should.equal(Ok(1.))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/metrics.variance\ngleam_community/maths/metrics variance","url":"gleam_community/maths/metrics.html#variance"},{"doc":"gleam_community/maths/metrics","title":"gleam_community/maths/metrics","content":"&lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.css&quot; integrity=&quot;sha384-GvrOXuhMATgEsSwCs4smul74iXGOixntILdUW9XmUC6+HX0sLNAK3q71HotJqlAn&quot; crossorigin=&quot;anonymous&quot;&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.js&quot; integrity=&quot;sha384-cpW21h6RZv/phavutF+AuVYrr+dA8xD9zs6FwLpaCct6O9ctzYFfFr4dgmgccOTx&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/contrib/auto-render.min.js&quot; integrity=&quot;sha384-+VBxd3r6XgURycqtZ117nYw44OOcIax56Z4dCRWbxyPt0Koah1uHoK0o4+/RRE05&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script&gt;\n    document.addEventListener(&quot;DOMContentLoaded&quot;, function() {\n        renderMathInElement(document.body, {\n          // customised options\n          // • auto-render specific keys, e.g.:\n          delimiters: [\n              {left: &#39;$$&#39;, right: &#39;$$&#39;, display: false},\n            //   {left: &#39;$&#39;, right: &#39;$&#39;, display: false},\n            //   {left: &#39;\\\\(&#39;, right: &#39;\\\\)&#39;, display: false},\n              {left: &#39;\\\\[&#39;, right: &#39;\\\\]&#39;, display: true}\n          ],\n          // • rendering keys, e.g.:\n          throwOnError : false\n        });\n    });\n&lt;/script&gt;\n&lt;style&gt;\n    .katex { font-size: 1.1em; }\n&lt;/style&gt;\n \n ---\n \n Metrics: A module offering functions for calculating distances and other types of metrics.\n \n * **Distances**\n   * [`norm`](#norm)\n   * [`manhatten_distance`](#float_manhatten_distance)\n   * [`minkowski_distance`](#minkowski_distance)\n   * [`euclidean_distance`](#euclidean_distance)\n * **Basic statistical measures**\n   * [`mean`](#mean)\n   * [`median`](#median)\n   * [`variance`](#variance)\n   * [`standard_deviation`](#standard_deviation)\n ","url":"gleam_community/maths/metrics.html"},{"doc":"gleam_community/maths/combinatorics","title":"cartesian_product","content":"pub fn cartesian_product(\n  xarr: List(a),\n  yarr: List(a),\n) -&gt; List(#(a, a))\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Generate a list containing all combinations of pairs of elements coming from two given lists.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/list\n     import gleam_community/maths/combinatorics\n\n     pub fn example () {\n       []\n       |&gt; combinatorics.cartesian_product([])\n       |&gt; should.equal([])\n     \n       [1.0, 10.0]\n       |&gt; combinatorics.cartesian_product([1.0, 2.0])\n       |&gt; should.equal([#(1.0, 1.0), #(1.0, 2.0), #(10.0, 1.0), #(10.0, 2.0)])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/combinatorics.cartesian_product\ngleam_community/maths/combinatorics cartesian_product","url":"gleam_community/maths/combinatorics.html#cartesian_product"},{"doc":"gleam_community/maths/combinatorics","title":"combination","content":"pub fn combination(n: Int, k: Int) -&gt; Result(Int, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A combinatorial function for computing the number of a $$k$$-combinations of $$n$$ elements:\n\n \\\\[\n C(n, k) = \\binom{n}{k} = \\frac{n!}{k! (n-k)!}\n \\\\]\n Also known as &quot;$$n$$ choose $$k$$&quot; or the binomial coefficient.\n\n The implementation uses the effecient iterative multiplicative formula for the computation.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/combinatorics\n\n     pub fn example() {\n       // Invalid input gives an error\n       // Error on: n = -1 &lt; 0\n       combinatorics.combination(-1, 1)\n       |&gt; should.be_error()\n\n       // Valid input returns a result\n       combinatorics.combination(4, 0)\n       |&gt; should.equal(Ok(1))\n\n       combinatorics.combination(4, 4)\n       |&gt; should.equal(Ok(1))\n\n       combinatorics.combination(4, 2)\n       |&gt; should.equal(Ok(6))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/combinatorics.combination\ngleam_community/maths/combinatorics combination","url":"gleam_community/maths/combinatorics.html#combination"},{"doc":"gleam_community/maths/combinatorics","title":"factorial","content":"pub fn factorial(n: Int) -&gt; Result(Int, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A combinatorial function for computing the total number of combinations of $$n$$\n elements, that is $$n!$$.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/combinatorics\n\n     pub fn example() {\n       // Invalid input gives an error\n       combinatorics.factorial(-1)\n       |&gt; should.be_error()\n\n       // Valid input returns a result\n       combinatorics.factorial(0)\n       |&gt; should.equal(Ok(1))\n \n       combinatorics.factorial(1)\n       |&gt; should.equal(Ok(1))\n \n       combinatorics.factorial(2)\n       |&gt; should.equal(Ok(2))\n \n       combinatorics.factorial(3)\n       |&gt; should.equal(Ok(6))\n \n       combinatorics.factorial(4)\n       |&gt; should.equal(Ok(24))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/combinatorics.factorial\ngleam_community/maths/combinatorics factorial","url":"gleam_community/maths/combinatorics.html#factorial"},{"doc":"gleam_community/maths/combinatorics","title":"list_combination","content":"pub fn list_combination(\n  arr: List(a),\n  k: Int,\n) -&gt; Result(List(List(a)), String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Generate all $$k$$-combinations based on a given list.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/set\n     import gleam_community/maths/combinatorics\n\n     pub fn example () {\n       let assert Ok(result) = combinatorics.list_combination([1, 2, 3, 4], 3)\n       result\n       |&gt; set.from_list()\n       |&gt; should.equal(set.from_list([[1, 2, 3], [1, 2, 4], [1, 3, 4], [2, 3, 4]]))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/combinatorics.list_combination\ngleam_community/maths/combinatorics list_combination","url":"gleam_community/maths/combinatorics.html#list_combination"},{"doc":"gleam_community/maths/combinatorics","title":"list_permutation","content":"pub fn list_permutation(arr: List(a)) -&gt; List(List(a))\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n Generate all permutations of a given list.\n\n Repeated elements are treated as distinct for the\n purpose of permutations, so two identical elements\n for example will appear &quot;both ways round&quot;. This\n means lists with repeated elements return the same\n number of permutations as ones without.\n\n N.B. The output of this function is a list of size\n factorial in the size of the input list. Caution is\n advised on input lists longer than ~11 elements, which\n may cause the VM to use unholy amounts of memory for\n the output.\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam/set\n     import gleam_community/maths/combinatorics\n\n     pub fn example () {\n       [1, 2, 3]\n       |&gt; combinatorics.list_permutation()\n       |&gt; set.from_list()\n       |&gt; should.equal(set.from_list([\n         [1, 2, 3],\n         [2, 1, 3],\n         [3, 1, 2],\n         [1, 3, 2],\n         [2, 3, 1],\n         [3, 2, 1],\n       ]))\n\n       [1.0, 1.0]\n       |&gt; combinatorics.list_permutation()\n       |&gt; should.equal([[1.0, 1.0], [1.0, 1.0]])\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/combinatorics.list_permutation\ngleam_community/maths/combinatorics list_permutation","url":"gleam_community/maths/combinatorics.html#list_permutation"},{"doc":"gleam_community/maths/combinatorics","title":"permutation","content":"pub fn permutation(n: Int, k: Int) -&gt; Result(Int, String)\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;https://github.com/gleam-community/maths/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\n A combinatorial function for computing the number of $$k$$-permuations (without repetitions)\n of $$n$$ elements:\n\n \\\\[\n P(n, k) = \\frac{n!}{(n - k)!}\n \\\\]\n\n &lt;details&gt;\n     &lt;summary&gt;Example:&lt;/summary&gt;\n\n     import gleeunit/should\n     import gleam_community/maths/combinatorics\n\n     pub fn example() {\n       // Invalid input gives an error\n       // Error on: n = -1 &lt; 0\n       combinatorics.permutation(-1, 1)\n       |&gt; should.be_error()\n\n       // Valid input returns a result\n       combinatorics.permutation(4, 0)\n       |&gt; should.equal(Ok(1))\n\n       combinatorics.permutation(4, 4)\n       |&gt; should.equal(Ok(1))\n\n       combinatorics.permutation(4, 2)\n       |&gt; should.equal(Ok(12))\n     }\n &lt;/details&gt;\n\n &lt;div style=&quot;text-align: right;&quot;&gt;\n     &lt;a href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\ngleam_community/maths/combinatorics.permutation\ngleam_community/maths/combinatorics permutation","url":"gleam_community/maths/combinatorics.html#permutation"},{"doc":"gleam_community/maths/combinatorics","title":"gleam_community/maths/combinatorics","content":"&lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.css&quot; integrity=&quot;sha384-GvrOXuhMATgEsSwCs4smul74iXGOixntILdUW9XmUC6+HX0sLNAK3q71HotJqlAn&quot; crossorigin=&quot;anonymous&quot;&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/katex.min.js&quot; integrity=&quot;sha384-cpW21h6RZv/phavutF+AuVYrr+dA8xD9zs6FwLpaCct6O9ctzYFfFr4dgmgccOTx&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script defer src=&quot;https://cdn.jsdelivr.net/npm/katex@0.16.8/dist/contrib/auto-render.min.js&quot; integrity=&quot;sha384-+VBxd3r6XgURycqtZ117nYw44OOcIax56Z4dCRWbxyPt0Koah1uHoK0o4+/RRE05&quot; crossorigin=&quot;anonymous&quot;&gt;&lt;/script&gt;\n&lt;script&gt;\n    document.addEventListener(&quot;DOMContentLoaded&quot;, function() {\n        renderMathInElement(document.body, {\n          // customised options\n          // • auto-render specific keys, e.g.:\n          delimiters: [\n              {left: &#39;$$&#39;, right: &#39;$$&#39;, display: false},\n            //   {left: &#39;$&#39;, right: &#39;$&#39;, display: false},\n            //   {left: &#39;\\\\(&#39;, right: &#39;\\\\)&#39;, display: false},\n              {left: &#39;\\\\[&#39;, right: &#39;\\\\]&#39;, display: true}\n          ],\n          // • rendering keys, e.g.:\n          throwOnError : false\n        });\n    });\n&lt;/script&gt;\n&lt;style&gt;\n    .katex { font-size: 1.1em; }\n&lt;/style&gt;\n \n ---\n \n Combinatorics: A module that offers mathematical functions related to counting, arrangements, and combinations. \n \n * **Combinatorial functions**\n   * [`combination`](#combination)\n   * [`factorial`](#factorial)\n   * [`permutation`](#permutation)\n   * [`list_combination`](#list_combination)\n   * [`list_permutation`](#list_permutation)\n   * [`cartesian_product`](#cartesian_product)\n ","url":"gleam_community/maths/combinatorics.html"}]);